@@ -1,11 +1,11 @@
-/* 
+/*
  * GChemUtils GOffice component
  * gchemutils.cc
  *
- * Copyright (C) 2005-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -27,7 +27,6 @@
 #include <gsf/gsf-impl-utils.h>
 #include <goffice/app/module-plugin-defs.h>
 #include <goffice/component/go-component-factory.h>
-#include <openbabel/mol.h>
 #include <libintl.h>
 #include <map>
 #include <string>
@@ -69,7 +68,7 @@ go_gchemutils_component_set_data (GOComponent *component)
 	gogcu->document = gogcu->application->ImportDocument (component->mime_type, component->data, component->length);
 	gogcu->application->UpdateBounds (gogcu);
 }
-	
+
 static void
 go_gchemutils_component_render (GOComponent *component, cairo_t *cr,
 						  double width, double height)
@@ -110,13 +109,6 @@ go_gchemutils_component_mime_type_set (GOComponent *component)
 	}
 }
 
-static void
-go_gchemutils_component_set_window (GOComponent *component)
-{
-	if (!strcmp (component->mime_type, "application/x-gcrystal")) {
-	}
-}
-
 static void
 go_gchemutils_component_finalize (GObject *obj)
 {
@@ -153,7 +145,6 @@ go_gchemutils_component_class_init (GOComponentClass *klass)
 	klass->render = go_gchemutils_component_render;
 	klass->edit = go_gchemutils_component_edit;
 	klass->mime_type_set = go_gchemutils_component_mime_type_set;
-	klass->set_window = go_gchemutils_component_set_window;
 }
 
 GSF_DYNAMIC_CLASS (GOGChemUtilsComponent, go_gchemutils_component,
