@@ -1,11 +1,11 @@
-/* 
+/*
  * GChemPaint GOffice component
- * gofficewin.cc
+ * gogcpwin.cc
  *
  * Copyright (C) 2006-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -71,6 +71,7 @@ void GOGcpWindow::OnSave ()
 	try {
 		xml = m_Document->BuildXMLTree ();
 		doc->Load (xml->children);
+		dynamic_cast <GOGcpApplication *> (m_Application)->UpdateBounds (m_gogcu);
 		xmlFreeDoc (xml);
 		xml = NULL;
 		m_Document->SetDirty (false);
