@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemistry Utils
- * gccv/text.cc 
+ * gccv/text.cc
  *
- * Copyright (C) 2008-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2008-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -235,16 +235,16 @@ void TextLine::DrawDecorations (cairo_t *cr, bool is_vector)
 			y -= width;
 			cairo_move_to (cr, xstart, y);
 			cairo_line_to (cr, xend, y);
-			break;	
+			break;
 		case TextDecorationLow:
 			y += width;
 			cairo_move_to (cr, xstart, y);
 			cairo_line_to (cr, xend, y);
-			break;	
+			break;
 		case TextDecorationMedium:
 			cairo_move_to (cr, xstart, y);
 			cairo_line_to (cr, xend, y);
-			break;	
+			break;
 		case TextDecorationDouble:
 			y += width;
 			cairo_move_to (cr, xstart, y);
@@ -252,9 +252,9 @@ void TextLine::DrawDecorations (cairo_t *cr, bool is_vector)
 			y -= 2 * width;
 			cairo_move_to (cr, xstart, y);
 			cairo_line_to (cr, xend, y);
-			break;	
+			break;
 		default:
-			break;	
+			break;
 		}
 		cairo_set_source_rgba (cr, GO_COLOR_TO_CAIRO (color));
 		cairo_set_line_width (cr, width);
@@ -800,7 +800,7 @@ void Text::InsertTextTag (TextTag *tag, bool rebuild_attributes)
 	std::list <TextTag *> new_tags, invalid;
 	TextTagList::iterator i, iend = m_Tags.end ();
 	TextTag *new_tag;
-	for (i = m_Tags.begin (); i != iend; i++) {
+	for (i = m_Tags.begin (); i !=iend; i++) {
 		new_tag = tag->Restrict (*i);
 		if (new_tag)
 			new_tags.push_back (new_tag);
@@ -868,7 +868,7 @@ void Text::ApplyTagsToSelection (TextTagList const *l)
 	// store tags to potentially insert into a vector
 	std::vector <TextTag *> new_tags (TextTag::MaxTag);
 	// fist set all vectors to NULL
-	for (int n = 0; n < MaxTag; n++) 
+	for (int n = 0; n < MaxTag; n++)
 		new_tags[n] = NULL;
 	// set the tags, unuseful ones will be reset to NULL later
 	for (j = l->begin (); j != jend; j++)
@@ -902,7 +902,7 @@ void Text::ApplyTagsToSelection (TextTagList const *l)
 		}
 	}
 	// Add new tags
-	for (int n = 0; n < TextTag::MaxTag; n++) 
+	for (int n = 0; n < TextTag::MaxTag; n++)
 		if (new_tags[n]) {
 			TextTag *tag = new_tags[n]->Duplicate ();
 			tag->SetStartIndex (start);
@@ -912,7 +912,7 @@ void Text::ApplyTagsToSelection (TextTagList const *l)
 			else
 				m_Tags.push_back (tag);
 		}
-	
+
 	// Add extra tags
 	iend = extra_tags.end ();
 	for (i = extra_tags.begin (); i != iend; i++)
@@ -940,7 +940,7 @@ void Text::ReplaceText (std::string &str, int pos, unsigned length)
 	if (length > 0) {
 		m_Text.erase (pos, length);
 		std::vector <TextTag *> borders (TextTag::MaxTag);
-		for (int n = 0; n < TextTag::MaxTag; n++) 
+		for (int n = 0; n < TextTag::MaxTag; n++)
 			borders[n] = NULL;
 		//TODO: update runs
 		for (i = m_Tags.begin (); i != iend; i++) {
@@ -1061,7 +1061,7 @@ void Text::ReplaceText (std::string &str, int pos, unsigned length)
 		else
 			m_Tags.push_back (*i);
 	new_tags.clear (); // avoid destroying the tags
-	
+
 	iend = extra_tags.end ();
 	for (i = extra_tags.begin (); i != iend; i++) {
 		TextTag *tag = (*i)->Duplicate ();
@@ -1091,11 +1091,11 @@ bool Text::OnKeyPressed (GdkEventKey *event)
 	}
 
 	switch (event->keyval) {
-	case GDK_Control_L:
-	case GDK_Control_R:
+	case GDK_KEY_Control_L:
+	case GDK_KEY_Control_R:
 		return false;
-	case GDK_Return:
-	case GDK_KP_Enter: {
+	case GDK_KEY_Return:
+	case GDK_KEY_KP_Enter: {
 		m_Text.insert (m_CurPos, "\n");
 		TextTag *tag = new NewLineTextTag ();
 		tag->SetStartIndex (m_CurPos++);
@@ -1108,14 +1108,14 @@ bool Text::OnKeyPressed (GdkEventKey *event)
 			client->TextChanged (m_CurPos);
 		return true;
 	}
-	case GDK_Tab:
+	case GDK_KEY_Tab:
 		TextPrivate::OnCommit (m_ImContext, "\t", this);
 		if (client)
 			client->TextChanged (m_CurPos);
 		break;
 
 	/* MOVEMENT */
-	case GDK_Right:
+	case GDK_KEY_Right:
 		if (m_CurPos == m_Text.length ())
 			break;
 		if (event->state & GDK_CONTROL_MASK) {
@@ -1143,7 +1143,7 @@ bool Text::OnKeyPressed (GdkEventKey *event)
 		if (client)
 			client->SelectionChanged (m_StartSel, m_CurPos);
 		break;
-	case GDK_Left:
+	case GDK_KEY_Left:
 		if (m_CurPos == 0)
 			break;
 		if (event->state & GDK_CONTROL_MASK) {
@@ -1171,42 +1171,42 @@ bool Text::OnKeyPressed (GdkEventKey *event)
 		if (client)
 			client->SelectionChanged (m_StartSel, m_CurPos);
 		break;
-	case GDK_f:
+	case GDK_KEY_f:
 		/* TODO: write this code */
 		break;
-	case GDK_b:
+	case GDK_KEY_b:
 		/* TODO: write this code */
 		break;
-	case GDK_p:
+	case GDK_KEY_p:
 		if (!(event->state & GDK_CONTROL_MASK))
 			break;
-	case GDK_Up:
+	case GDK_KEY_Up:
 		/* TODO: write this code */
 		break;
-	case GDK_n:
+	case GDK_KEY_n:
 		if (!(event->state & GDK_CONTROL_MASK))
 			break;
-	case GDK_Down:
+	case GDK_KEY_Down:
 		/* TODO: write this code */
 		break;
-	case GDK_Home:
+	case GDK_KEY_Home:
 		/* TODO: write this code */
 		break;
-	case GDK_End:
+	case GDK_KEY_End:
 		/* TODO: write this code */
 		break;
-	case GDK_a:
+	case GDK_KEY_a:
 		/* TODO: write this code */
 		break;
-	case GDK_e:
+	case GDK_KEY_e:
 		/* TODO: write this code */
 		if (event->state & GDK_CONTROL_MASK) {
 		}
 		break;
 
 	/* DELETING TEXT */
-	case GDK_Delete:
-	case GDK_KP_Delete: {
+	case GDK_KEY_Delete:
+	case GDK_KEY_KP_Delete: {
 		if (m_CurPos != m_StartSel) {
 			ReplaceText (empty_st, MIN (m_CurPos, m_StartSel), abs (m_CurPos - m_StartSel));
 			if (client)
@@ -1223,10 +1223,10 @@ bool Text::OnKeyPressed (GdkEventKey *event)
 			client->TextChanged (m_CurPos);
 		break;
 	}
-	case GDK_d:
+	case GDK_KEY_d:
 		/* TODO: write this code */
 		break;
-	case GDK_BackSpace: {
+	case GDK_KEY_BackSpace: {
 		if (m_CurPos != m_StartSel) {
 			ReplaceText (empty_st, MIN (m_CurPos, m_StartSel), abs (m_CurPos - m_StartSel));
 			if (client)
@@ -1243,19 +1243,19 @@ bool Text::OnKeyPressed (GdkEventKey *event)
 			client->TextChanged (m_CurPos);
 		break;
 	}
-	case GDK_k:
+	case GDK_KEY_k:
 		if (event->state & GDK_CONTROL_MASK) {
 			/* delete from cursor to end of paragraph */
 			/* TODO: write this code */
 		}
 		break;
-	case GDK_u:
+	case GDK_KEY_u:
 		if (event->state & GDK_CONTROL_MASK) {
 			/* delete whole paragraph */
 			/* TODO: write this code */
 		}
 		break;
-	case GDK_backslash:
+	case GDK_KEY_backslash:
 		if (event->state & GDK_MOD1_MASK) {
 			/* delete all white spaces around the cursor */
 			/* TODO: write this code */
