@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * application.h 
+ * application.h
  *
- * Copyright (C) 2004-2009 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -25,7 +25,7 @@
 #ifndef GCHEMPAINT_APPLICATION_H
 #define GCHEMPAINT_APPLICATION_H
 
-#include <gcu/application.h>
+#include <gcugtk/application.h>
 #include <gcu/macros.h>
 #include <libxml/parser.h>
 #include <set>
@@ -33,6 +33,10 @@
 #include <map>
 #include <stdexcept>
 
+namespace gccv {
+	class Canvas;
+}
+
 namespace gcu {
 	class Dialog;
 	class Object;
@@ -58,16 +62,20 @@ The name of the icon.
 */
 	char const *name;
 /*!
-The icon as in line bytes.
+The icon as in line bytes or NULL (when using a canvas instead of a bitmap).
 */
 	unsigned char const *data_24;
+/*!
+	The 24*24 canvas used to display the icon.
+*/
+	gccv::Canvas *canvas;
 } IconDesc;
 
 class Target;
 class NewFileDlg;
 class Tool;
 class Document;
-typedef void (*BuildMenuCb) (GtkUIManager *UIManager);
+typedef void (*BuildMenuCb) (gcu::UIManager *UIManager);
 
 /*!
 @brief Cursors.
@@ -89,14 +97,14 @@ typedef enum {
 This class is used to represent a GChemPaint application.
 It is a virtual class since at least one method is pure virtual (gcp::Application::GetWindow)
 */
-class Application: public gcu::Application
+class Application: public gcugtk::Application
 {
 friend class ApplicationPrivate;
 public:
 /*!
 The default constructor.
 */
-	Application (gcu::CmdContext *cc = NULL);
+	Application (gcugtk::CmdContextGtk *cc = NULL);
 /*!
 The destructor.
 */
@@ -120,13 +128,13 @@ To activate the selection tool:
 @param activate whether to activate or deactivate.
 
 Activates or deactivates the menu item corresponding to \a path according
-to the value of \a activate. 
+to the value of \a activate.
 
 To deactivate the "Paste" menu item, use:
 \code
 		 ActivateWindowsActionWidget ("/MainMenu/EditMenu/Paste", false);
 \endcode
-			 
+
 Calls gcp::Window::ActivateActionWidget.
 */
 	void ActivateWindowsActionWidget (const char *path, bool activate);
@@ -373,12 +381,12 @@ adds a callback for adding entries to the windows menus.
 	void AddMenuCallback (BuildMenuCb cb);
 
 /*!
-@param manager: the GtkUIManager to populate.
+@param manager: the gcu::UIManager to populate.
 
 Populates the user interface by calling all callbacks registered
 with AddMenuCallback.
 */
-	void BuildMenu (GtkUIManager *manager);
+	void BuildMenu (gcu::UIManager *manager);
 
 /*!
 Creates a new document using the default theme.
@@ -404,6 +412,7 @@ it is pure virtual.
 	GdkCursor *GetCursor (CursorId id)  {return m_Cursors[id];}
 
 	bool Have3DSupport () {return m_HaveGhemical | m_HaveGChem3D | m_HaveAvogadro;}
+	void AddCanvas (char const *path, gccv::Canvas *canvas) {m_ToolCanvases[path] = canvas;}
 
 protected:
 /*!
@@ -424,7 +433,7 @@ Shows or hides the tools box.
 	void ShowTools (bool visible);
 
 private:
-	void TestSupportedType (char const *mime_type);
+	void TestSupportedType (char const *mime_type, char const* babel_type = NULL, bool writeable = false);
 	void AddMimeType (std::list<std::string> &l, std::string const& mime_type);
 	void UpdateAllTargets ();
 
@@ -466,17 +475,21 @@ private:
 	gcu::Object *m_Dummy;
 	std::list<BuildMenuCb> m_MenuCbs;
 	GdkCursor *m_Cursors[CursorMax];
+	std::map < std::string, gccv::Canvas * >m_ToolCanvases;
 
+#if 0
 /*!\fn GetStyle()
 @return the default GtkStyle for the windows.
 */
 	GCU_RO_POINTER_PROP	(GtkStyle, Style)
+#endif
 /*!\fn GetHaveGhemical
 @return true if ghemical is usable on startup.
 */
-	GCU_RO_STATIC_PROP (bool, HaveGhemical);
-	GCU_RO_STATIC_PROP (bool, HaveGChem3D);
-	GCU_RO_STATIC_PROP (bool, HaveAvogadro);
+	GCU_RO_STATIC_PROP (bool, HaveGhemical)
+	GCU_RO_STATIC_PROP (bool, HaveGChem3D)
+	GCU_RO_STATIC_PROP (bool, HaveAvogadro)
+	GCU_RO_PROP (bool, UseAtomColors)
 };
 
 }	// namespace gcp
