@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * bond.h 
+ * bond.h
  *
- * Copyright (C) 2001-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -31,6 +31,10 @@
 #include <gcu/bond.h>
 #include <list>
 
+namespace gcu {
+class UIManager;
+}
+
 namespace gcp {
 
 /*!\enum BondType gcp/bond.h
@@ -166,7 +170,7 @@ Loads properties specific to GChemPaint bonds.
 @param z the z component of the transation vector.
 
 Used to move a bond. Just tells the bond it has been moved and that it's
-coordinates need to be reevaluated from the new atomic positions. 
+coordinates need to be reevaluated from the new atomic positions.
 */
 	void Move (double x, double y, double z = 0);
 /*!
@@ -235,14 +239,14 @@ condition.
 */
 	bool IsCrossing (Bond *pBond);
 /*!
-@param UIManager: the GtkUIManager to populate.
+@param UIManager: the gcu::UIManager to populate.
 @param object the atom on which occured the mouse click.
 @param x x coordinate of the mouse click.
 @param y y coordinate of the mouse click.
 
 This method is called to build a contextual menu for the atom.
 */
-	bool BuildContextualMenu (GtkUIManager *UIManager, Object *object, double x, double y);
+	bool BuildContextualMenu (gcu::UIManager *UIManager, Object *object, double x, double y);
 /*!
 Move the bond to the lowest position. It has an effect only for crossing bonds.
 */
