@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * docprop.h 
+ * docprop.h
  *
- * Copyright (C) 2002-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -25,7 +25,7 @@
 #ifndef GCHEMPAINT_DOC_PROP_H
 #define GCHEMPAINT_DOC_PROP_H
 
-#include <gcu/dialog.h>
+#include <gcugtk/dialog.h>
 #include <gcu/object.h>
 #include <gcu/macros.h>
 
@@ -38,9 +38,10 @@ class Theme;
 /*!\class DocPropDlg gcp/docprop.h
 The document property dialog.
 */
-class DocPropDlg: public gcu::Dialog, gcu::Object
+class DocPropDlg: public gcugtk::Dialog, gcu::Object
 {
 public:
+friend class DocPropPrivate;
 /*!
 @param pDoc the document.
 
@@ -51,7 +52,7 @@ Constructs a property dialog for \a pDoc.
 The destructor.
 */
 	virtual ~DocPropDlg ();
-	
+
 /*!
 Called by the framework to update themes names.
 */
@@ -86,14 +87,18 @@ Called by the framework when the author mail changed.
 Called by the framework when the document comments changed.
 */
 	void OnCommentsChanged (char const *title);
-	
+
 private:
 	Document* m_pDoc;
-	GtkEntry *Title, *Name, *Mail;
+	GtkEntry *Title, *NameEntry, *Mail;
 	GtkLabel *CreationDate, *RevisionDate;
 	GtkTextView *Comments;
 	GtkTextBuffer *Buffer;
+#if GTK_CHECK_VERSION (2, 24, 0)
+	GtkComboBoxText *m_Box;
+#else
 	GtkComboBox *m_Box;
+#endif
 	unsigned m_Lines;
 	gulong m_ChangedSignal;
 };
