@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * document.cc 
+ * document.cc
  *
  * Copyright (C) 2001-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -101,6 +101,7 @@ Document::Document (Application *App, bool StandAlone, Window *window):
 	SetActive ();
 	m_AllowClipboard = true;
 	m_SoftwareVersion = 0;
+	m_UseAtomColors = false;
 }
 
 Document::~Document ()
@@ -225,12 +226,12 @@ void Document::DoPrint (G_GNUC_UNUSED GtkPrintOperation *print, GtkPrintContext
 	cairo_rectangle (cr, 0, 0, width, height);
 	cairo_clip (cr);
 	switch (GetScaleType ()) {
-	case GCU_PRINT_SCALE_NONE:
+	case gcugtk::GCU_PRINT_SCALE_NONE:
 		break;
-	case GCU_PRINT_SCALE_FIXED:
+	case gcugtk::GCU_PRINT_SCALE_FIXED:
 		scale *= Printable::GetScale ();
 		break;
-	case GCU_PRINT_SCALE_AUTO:
+	case gcugtk::GCU_PRINT_SCALE_AUTO:
 		if (GetHorizFit () && GetVertFit ())
 			scale *= min (width / w, height / h);
 		else if (GetHorizFit ())
@@ -395,10 +396,13 @@ void Document::Save () const
 		return;
 	xmlDocPtr xml = NULL;
 	const_cast <Document *> (this)->m_SavedResidues.clear ();
-	
+
 	try {
-		if (m_pApp && m_pApp->Save (m_filename, m_FileType.c_str (), this, ContentType2D))
+		if (m_FileType.length () && m_FileType != "application/x-gchempaint") {
+			if (!m_pApp || !m_pApp->Save (m_filename, m_FileType.c_str (), this, ContentType2D))
+				throw (int) -1; // FIXME: really display an error message
 			return;
+		}
 		xml = BuildXMLTree ();
 		xmlSetDocCompressMode (xml, CompressionLevel);
 
@@ -406,7 +410,7 @@ void Document::Save () const
 			xmlIndentTreeOutput = true;
 			xmlKeepBlanksDefault (0);
 		}
-	
+
 		xmlOutputBufferPtr buf = xmlAllocOutputBuffer (NULL);
 		GFile *file = g_file_new_for_uri (m_filename);
 		GError *error = NULL;
@@ -475,6 +479,11 @@ bool Document::Load (xmlNodePtr root)
 		SetId (tmp);
 		xmlFree (tmp);
 	}
+	tmp = reinterpret_cast < char * > (xmlGetProp (root, reinterpret_cast < xmlChar const * > ("use-atom-colors")));
+	if (tmp) {
+		m_UseAtomColors = !strcmp (tmp, "true");
+		xmlFree (tmp);
+	}
 
 	gcu::ReadDate (root, "creation", &CreationDate);
 	gcu::ReadDate (root, "revision", &RevisionDate);
@@ -567,7 +576,7 @@ bool Document::Load (xmlNodePtr root)
 	m_pView->EnsureSize ();
 	return true;
 }
-	
+
 void Document::ParseXMLTree (xmlDocPtr xml)
 {
 	Load (xml->children);
@@ -580,13 +589,15 @@ xmlDocPtr Document::BuildXMLTree () const
 	xmlNsPtr ns;
 
 	xml = xmlNewDoc ((xmlChar*) "1.0");
-//FIXME: do something if an error occurs 
+//FIXME: do something if an error occurs
 	if (xml == NULL)
 		throw (int) 0;
-	
+
 	xmlDocSetRootElement (xml,  xmlNewDocNode (xml, NULL, (xmlChar*) "chemistry", NULL));
 	ns = xmlNewNs (xml->children, (xmlChar*) "http://www.nongnu.org/gchempaint", (xmlChar*) "gcp");
 	xmlSetNs (xml->children, ns);
+	if (m_UseAtomColors)
+		xmlNewProp (xml->children, reinterpret_cast < xmlChar const * > ("use-atom-colors"), reinterpret_cast < xmlChar const * > ("true"));
 	if (!g_date_valid (&CreationDate))
 		g_date_set_time_t (&const_cast <Document *> (this)->CreationDate, time (NULL));
 	g_date_set_time_t (&const_cast <Document *> (this)->RevisionDate, time (NULL));
@@ -657,7 +668,7 @@ void Document::Update ()
 		delete *i;
 	m_DirtyObjects.clear ();
 }
-	
+
 void Document::RemoveAtom (Atom* pAtom)
 {
 	std::map<gcu::Atom*, gcu::Bond*>::iterator i;
@@ -765,7 +776,7 @@ void Document::RemoveBond (Bond* pBond)
 	m_DirtyObjects.erase (pBond);
 	delete pBond;
 }
-	
+
 void Document::Remove (Object* pObject)
 {
 	switch(pObject->GetType ())
@@ -807,7 +818,7 @@ void Document::Remove (Object* pObject)
 			break;
 	}
 }
-	
+
 void Document::Remove (const char* Id)
 {
 	Object* pObj = GetDescendant (Id);
@@ -845,7 +856,7 @@ void Document::SetComment (const gchar* comment)
 	g_free (m_comment);
 	m_comment = (comment && *comment)? g_strdup (comment): NULL;
 }
-	
+
 void Document::AddObject (Object* pObject)
 {
 	if (!pObject->GetParent ())
@@ -935,11 +946,11 @@ void Document::FinishOperation ()
 }
 
 void Document::AbortOperation()
-{ 
+{
 	if (m_pCurOp)
 		delete m_pCurOp;
 	m_pCurOp = NULL;
-} 
+}
 
 void Document::PopOperation ()
 {
@@ -1121,12 +1132,12 @@ void Document::SetTheme (Theme *theme)
 	m_BondLength = theme->GetBondLength ();
 	m_BondAngle = theme->GetBondAngle ();
 	m_ArrowLength = theme->GetArrowLength ();
-	m_TextFontFamily = theme->GetTextFontFamily ();
+	m_BracketsFontFamily = m_TextFontFamily = theme->GetTextFontFamily ();
 	m_TextFontStyle = theme->GetTextFontStyle ();
 	m_TextFontWeight = theme->GetTextFontWeight ();
 	m_TextFontVariant = theme->GetTextFontVariant ();
 	m_TextFontStretch = theme->GetTextFontStretch ();
-	m_TextFontSize = theme->GetTextFontSize ();
+	m_BracketsFontSize = m_TextFontSize = theme->GetTextFontSize ();
 	pango_attr_list_unref (m_PangoAttrList);
 	m_PangoAttrList = pango_attr_list_new ();
 	pango_attr_list_insert (m_PangoAttrList, pango_attr_family_new (theme->GetFontFamily ()));
@@ -1253,7 +1264,7 @@ bool Document::SetProperty (unsigned property, char const *value)
 		double length = strtod (value, &end);
 		if (*end != 0)
 			return false;
-		gcu::Document::SetScale (m_Theme->GetBondLength () / length); 
+		gcu::Document::SetScale (m_Theme->GetBondLength () / length);
 		break;
 	}
 	}
