@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * document.h 
+ * document.h
  *
- * Copyright (C) 2001-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -28,8 +28,9 @@
 #include "operation.h"
 #include <gcu/document.h>
 #include <gcu/macros.h>
-#include <gcu/printable.h>
+#include <gcugtk/printable.h>
 #include <gcu/residue.h>
+#include <gcugtk/printable.h>
 #include <list>
 #include <map>
 #include <set>
@@ -74,7 +75,7 @@ class Molecule;
 /*!\class Document gcp/document.h
 The document class for GChemPaint.
 */
-class Document: public gcu::Document, public gcu::Printable
+class Document: public gcu::Document, public gcugtk::Printable
 {
 	//Constructor and destructor
 public:
@@ -107,16 +108,6 @@ Empties a document and reinitialize it.
 */
 	View* GetView () {return m_pView;}
 /*!
-@param Mol an OpenBabel molecule to import.
-
-Imports a molecule using OpenBabel.
-*/
-	bool ImportOB (OpenBabel::OBMol& Mol);
-/*!
-Exports the current file using OpenBabel. Only molecules will be exported.
-*/
-	void ExportOB () const;
-/*!
 Saves the current file.
 */
 	void Save () const;
@@ -459,9 +450,9 @@ of the residue.
 */
 	gcu::Residue *CreateResidue (char const *name, char const *symbol, gcu::Molecule *molecule);
 
+	std::set <std::string> &GetNewObjects () {return m_NewObjects;}
+
 private:
-	void BuildBondList (std::list<Bond*>& BondList, gcu::Object const *obj) const;
-	void BuildAtomTable (std::map<std::string, unsigned>& AtomTable, gcu::Object const *obj, unsigned& index) const;
 	void RemoveAtom (Atom* pAtom);
 	void RemoveBond (Bond* pBond);
 	void RemoveFragment (Fragment* pFragment);
@@ -485,6 +476,7 @@ private:
 	unsigned m_LastStackSize; // undo list size when last saved
 	std::set<Residue const *> m_SavedResidues;
 	std::map<std::string, gcu::SymbolResidue> m_Residues;
+	std::set <std::string> m_NewObjects;
 
 /* Theme is not really a read only property, but we provide a special Set
 method */
@@ -628,6 +620,31 @@ the micro version. This is used to detect files with old syntax on loading.
 @return the GChemPaint API version which last saved the file.
 */
 GCU_RO_PROP (unsigned, SoftwareVersion)
+/*!\fn SetBracketsFontFamily(char* val)
+@param val the new brackets font family.
+
+Sets the new current brackets font family for the document.
+*/
+/*!\fn GetBracketsFontFamily()
+@return the current brackets font family.
+*/
+/*!\fn GetRefBracketsFontFamily()
+@return the current brackets font family as a reference.
+*/
+GCU_PROP (std::string, BracketsFontFamily)
+/*!\fn SetBracketsFontSize(int val)
+@param val the new brackets font size.
+
+Sets the new current text font size for the document.
+*/
+/*!\fn GetBracketsFontSize()
+@return the current brackets font size.
+*/
+/*!\fn GetRefBracketsFontSize()
+@return the current brackets font size as a reference.
+*/
+GCU_PROP (int, BracketsFontSize)
+GCU_PROP (bool, UseAtomColors)
 };
 
 }	//	namespace gcp
