@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * fragment.cc 
+ * fragment.cc
  *
- * Copyright (C) 2002-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -465,6 +465,11 @@ void Fragment::AddItem ()
 		m_Atom->SetChargeItem (text);
 	} else
 		m_Atom->SetChargeItem (NULL);
+	// update the size
+	gccv::Rect rect;
+	m_TextItem->GetBounds (&rect, NULL);
+	m_length = rect.x1 - rect.x0;
+	m_height = rect.y1 - rect.y0;
 }
 
 void Fragment::UpdateItem ()
@@ -517,11 +522,9 @@ void Fragment::UpdateItem ()
 void Fragment::SetSelected (int state)
 {
 	GOColor color, othercolor = 0;
-	bool visible = true;
-	switch (state) {	
+	switch (state) {
 	case SelStateUnselected:
 		color = GO_COLOR_BLACK;
-		visible = false;
 		break;
 	case SelStateSelected:
 		color = SelectColor;
@@ -596,7 +599,7 @@ bool Fragment::SavePortion (xmlDocPtr xml, xmlNodePtr node, unsigned start, unsi
 	for (j = tags->begin (); j != jend; j++) {
 		if (end <= (*j)->GetStartIndex () || start >= (*j)->GetEndIndex ())
 			continue;
-		if (start < (*j)->GetStartIndex ()) 
+		if (start < (*j)->GetStartIndex ())
 			xmlNodeAddContentLen (node, reinterpret_cast <xmlChar const *> (m_buf.c_str () + start), (*j)->GetStartIndex () - start);
 		gccv::Tag tag = (*j)->GetTag ();
 		if (tag == gccv::Position) {
@@ -683,6 +686,7 @@ bool Fragment::Load (xmlNodePtr node)
 	char* tmp;
 	double size = (double) pTheme->GetFontSize () / PANGO_SCALE;
 	gccv::TextTag *tag;
+	m_Atom->SetId ("a0"); // avoids confusion with another atom while loading
 	while (child) {
 		if (!strcmp ((const char*) child->name, "text")) {
 			tmp = (char*) xmlNodeGetContent (child);
@@ -690,13 +694,13 @@ bool Fragment::Load (xmlNodePtr node)
 				m_buf += tmp;
 			xmlFree (tmp);
 		} else if (!strcmp ((const char*) child->name, "atom")) {
+			AddChild (m_Atom);
 			if (!m_Atom->Load (child))
 				return false;
 			m_BeginAtom = m_buf.length ();
 			m_buf += m_Atom->GetSymbol();
 			m_Atom->SetCoords (m_x, m_y);
 			m_EndAtom = m_buf.length ();
-			AddChild (m_Atom);
 		} else if (!strcmp ((const char*) child->name, "residue")) {
 			// replace the atom by a residue
 			map<gcu::Atom*, gcu::Bond*>::iterator i;
@@ -817,6 +821,7 @@ bool Fragment::Load (xmlNodePtr node)
 	}
 	m_bLoading = false;
 	pDoc->ObjectLoaded (this);
+	pDoc->ObjectLoaded (m_Atom);
 	return true;
 }
 
@@ -860,7 +865,7 @@ void Fragment::AnalContent (unsigned start, unsigned &end)
 				}
 				if ((*i)->GetTag () == StoichiometryTag) {
 					tag =*i;
-					Stoich = true; 
+					Stoich = true;
 					break;
 				}
 			}}
@@ -1071,8 +1076,6 @@ Object* Fragment::GetAtomAt (double x, double y, G_GNUC_UNUSED double z)
 		return NULL;
 	if (m_Atom->GetBondsNumber () || m_Atom->GetCharge ())
 		return m_Atom;
-	if (!pDoc)
-		return NULL;
 	double x0, y0;
 	x0 = (x - m_x) * pTheme->GetZoomFactor () + m_lbearing;
 	y0 = (y - m_y) * pTheme->GetZoomFactor () + m_ascent;
@@ -1081,6 +1084,8 @@ Object* Fragment::GetAtomAt (double x, double y, G_GNUC_UNUSED double z)
 	unsigned index, trailing;
 	int cur;
 	index = m_TextItem->GetIndexAt (x0, y0);
+	if (index > 0)
+		index--;
 	char c = m_buf[index];
 	cur = index;
 	while ((c >= 'a') && (c <= 'z') && cur >= 0) {
@@ -1172,7 +1177,7 @@ Object* Fragment::GetAtomAt (double x, double y, G_GNUC_UNUSED double z)
 		m_x += m_lbearing / pTheme->GetZoomFactor ();
 		m_Atom->SetCoords(m_x, m_y);
 	}
-	
+
 	return m_Atom;
 }
 
@@ -1359,7 +1364,7 @@ bool Fragment::Validate ()
 			}
 			unsigned length = (*it)->GetEndIndex () - (*it)->GetStartIndex () - (err - charge);
 			if ((*err == '+' && length == 1) ||
-			    (!strcmp (err, "−") && length == strlen ("−")))
+			    (!strncmp (err, "−", strlen ("−")) && length == strlen ("−")))
 				continue;
 			// if we are there, we have an error
 			Document *pDoc = dynamic_cast<Document*> (GetDocument ());
@@ -1389,7 +1394,7 @@ void Fragment::Transform2D (Matrix2D& m, double x, double y)
 	m_y += y;
 	m_Atom->SetCoords (m_x, m_y);
 }
-	
+
 double Fragment::GetYAlign ()
 {
 	return m_y;
