@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * reaction-step.cc 
+ * reaction-step.cc
  *
  * Copyright (C) 2004-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -108,9 +108,10 @@ ReactionStep::~ReactionStep ()
 {
 	if (IsLocked ())
 		return;
+	Lock ();
 	CleanChildren ();
 }
-	
+
 xmlNodePtr ReactionStep::Save (xmlDocPtr xml) const
 {
 	xmlNodePtr node;
@@ -131,12 +132,20 @@ xmlNodePtr ReactionStep::Save (xmlDocPtr xml) const
 	}
 	return node;
 }
-	
+
 bool ReactionStep::Load (xmlNodePtr node)
 {
-	m_bLoading = true;
 	if (!Object::Load (node))
 		return false;
+	Document *pDoc = dynamic_cast <Document*> (GetDocument ());
+	pDoc->NotifyDirty (this);
+	pDoc->ObjectLoaded (this);
+	return true;
+}
+
+void ReactionStep::OnLoaded ()
+{
+	m_bLoading = true;
 	map<Object*, gccv::Rect> Objects;
 	map<double, Object*> Children;
 	gccv::Rect rect;
@@ -145,11 +154,16 @@ bool ReactionStep::Load (xmlNodePtr node)
 	Document *pDoc = dynamic_cast <Document*> (GetDocument ());
 	View *view = pDoc->GetView ();
 	Theme *pTheme = pDoc->GetTheme ();
+	view->Update (this);
 	WidgetData  *pData= view->GetData ();
 	map<double, Object*>::iterator im, endm;
 	double x, y, x0, y0, x1, y1;
+	// this method is called more than once (might consider this a bug) so we need to remove old operators
+	std::list <gcu::Object *> Operators;
 	while (pObj) {
-		if (pObj->GetType () != gcp::MechanismArrowType) {
+		if (pObj->GetType () == ReactionOperatorType)
+			Operators.push_front (pObj);
+		else if (pObj->GetType () != gcp::MechanismArrowType) {
 			pData->GetObjectBounds (pObj, &rect);
 			x = (rect.x0 + rect.x1) / 2;
 			while (Children[x] != NULL)
@@ -159,6 +173,10 @@ bool ReactionStep::Load (xmlNodePtr node)
 		}
 		pObj = GetNextChild (i);
 	}
+	while (!Operators.empty ()) {
+		delete Operators.front ();
+		Operators.pop_front ();
+	}
 	im = Children.begin ();
 	endm = Children.end ();
 	rect = Objects[(*im).second];
@@ -178,9 +196,7 @@ bool ReactionStep::Load (xmlNodePtr node)
 		rect = Objects[pObj];
 		x+= rect.x1 - rect.x0;
 	}
-	view->Update (this);
 	m_bLoading = false;
-	return true;
 }
 
 double ReactionStep::GetYAlign ()
@@ -209,20 +225,32 @@ bool ReactionStep::OnSignal (SignalId Signal, G_GNUC_UNUSED Object *Child)
 		WidgetData  *pData= (WidgetData*) g_object_get_data (G_OBJECT (pDoc->GetWidget ()), "data");
 		map<double, Object*>::iterator im, endm;
 		double x, y, x0, y0, x1, y1;
+		std::set <gcu::Object *> Invalid;
 		while (pObj) {
 			if (pObj->GetType () == ReactionOperatorType)
 				Operators.push_front (pObj);
 			else if (pObj->GetType () == MechanismArrowType); // don't do anything
 			else {
-				pData->GetObjectBounds (pObj, &rect);
-				x = (rect.x0 + rect.x1) / 2;
-				while (Children[x] != NULL)
-					x += 1e-5;
-				Children[x] = pObj;
-				Objects[pObj] = rect;
+				if (pObj->GetChildrenNumber ()) {
+					pData->GetObjectBounds (pObj, &rect);
+					x = (rect.x0 + rect.x1) / 2;
+					while (Children[x] != NULL)
+						x += 1e-5;
+					Children[x] = pObj;
+					Objects[pObj] = rect;
+				} else
+					Invalid.insert (pObj);
 			}
 			pObj = GetNextChild (i);
 		}
+		// delete invalid children
+		// first avoid new signals
+		m_bLoading = true;
+		// really delete
+		std::set <gcu::Object *>::iterator j, jend = Invalid.end ();
+		for (j = Invalid.begin (); j != jend; j++)
+			delete *j;
+		m_bLoading = false;
 		while (!Operators.empty ()) {
 			pObj = Operators.front ();
 			pView->Remove (pObj);
@@ -347,7 +375,7 @@ void ReactionStep::CleanChildren ()
 					step->AddChild (obj);
 					obj = parent->GetFirstChild (it);
 				}
-				
+
 			} else
 				step->AddChild (molecule);
 		}
