@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * reaction.h 
+ * reaction.h
  *
- * Copyright (C) 2002-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -29,6 +29,11 @@
 #include <stdexcept>
 
 /*!\file*/
+
+namespace gcu {
+class UIManager;
+}
+
 namespace gcp {
 
 /*!\class Reaction gcp/reaction.h
@@ -60,12 +65,12 @@ children are molecules and texts to be used as reactants or products, and
 reaction arrows.
 @return true in case of success and false if failed.
 */
-	bool Build (std::list<gcu::Object*>& Children) throw (std::invalid_argument);
+	bool Build (std::set < Object * > const &Children) throw (std::invalid_argument);
 /*!
 */
 	void Transform2D (gcu::Matrix2D& m, double x, double y);
 /*!
-@param UIManager the GtkUIManager to populate.
+@param UIManager the gcu::UIManager to populate.
 @param object the Object on which occured the mouse click.
 @param x x coordinate of the mouse click.
 @param y y coordinate of the mouse click.
@@ -73,7 +78,7 @@ reaction arrows.
 This method is called to build a contextual menu for the reaction.
 @return true if something is added to the UIManager, false otherwise.
 */
-	bool BuildContextualMenu (GtkUIManager *UIManager, gcu::Object *object, double x, double y);
+	bool BuildContextualMenu (gcu::UIManager *UIManager, gcu::Object *object, double x, double y);
 /*!
 @param Signal the appropriate SignalId
 @param Child the child which emitted the signal or NULL
@@ -93,11 +98,14 @@ Used to load an reaction in memory.
 */
 	bool Load (xmlNodePtr node);
 /*!
-Used to retrieve the y coordinate for alignment. 
+Used to retrieve the y coordinate for alignment.
 @return y coordinate used for the reaction alignment.
 */
 	double GetYAlign ();
 
+/*!
+@return the localized object generic name.
+*/
 	std::string Name ();
 };
 
