@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * tools.cc 
+ * tools.cc
  *
- * Copyright (C) 2001-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -27,9 +27,8 @@
 #include "settings.h"
 #include "tool.h"
 #include "tools.h"
+#include <gcugtk/ui-manager.h>
 #include <gcu/element.h>
-#include <gcu/gtkcomboperiodic.h>
-#include <goffice/gtk/go-combo-box.h>
 #include <cstring>
 
 using namespace gcu;
@@ -53,30 +52,28 @@ static void help_cb (Tools *box)
 }
 
 Tools::Tools (Application *App):
-	Dialog (App, GLADEDIR"/tools.glade", "tools", App),
+	gcugtk::Dialog (App, UIDIR"/tools.ui", "tools", GETTEXT_PACKAGE, App),
 	m_UIManager (NULL)
 {
-	if (!xml) {
-		delete this;
-		return;
-	}
 	g_signal_connect (G_OBJECT (dialog), "delete-event", G_CALLBACK (on_delete_event), NULL);
 	Application *pApp = dynamic_cast<Application*> (App);
 	m_UIManager = NULL;
-	m_ButtonsBox = GTK_BOX (glade_xml_get_widget (xml, "tools-buttons"));
-	m_Book = GTK_NOTEBOOK (glade_xml_get_widget (xml, "tools-book"));
-	GtkWidget *w = glade_xml_get_widget (xml, "mendeleiev");
-	gtk_combo_periodic_set_element (GTK_COMBO_PERIODIC (w), pApp->GetCurZ ());
-	go_combo_box_set_tearable (GO_COMBO_BOX (w), TearableMendeleiev);
+	m_ButtonsGrid = GTK_GRID (GetWidget ("tools-buttons"));
+	m_Book = GTK_NOTEBOOK (GetWidget ("tools-book"));
+	GtkWidget *grid = GetWidget ("element-grid");
+	GtkWidget *w = gcu_combo_periodic_new ();
+	m_Mendeleiev = reinterpret_cast <GcuComboPeriodic *> (w);
+	gtk_container_add (GTK_CONTAINER (grid), w);
+	gcu_combo_periodic_set_element (GCU_COMBO_PERIODIC (w), pApp->GetCurZ ());
 	g_signal_connect_swapped (G_OBJECT (w), "changed", G_CALLBACK (element_changed_cb), this);
-	w = glade_xml_get_widget (xml, "help-btn");
+	w = GetWidget ("help-btn");
 	g_signal_connect_swapped (G_OBJECT (w), "clicked", G_CALLBACK (help_cb), this);
 }
 
 Tools::~Tools ()
 {
 	if (m_UIManager) {
-		g_object_unref (m_UIManager);
+		delete m_UIManager;
 		m_UIManager = NULL;
 	}
 }
@@ -100,21 +97,21 @@ void register_item_cb (GtkWidget *w, Tools *Dlg)
 void Tools::AddToolbar (string &name)
 {
 	if (m_UIManager) {
-		GtkWidget *w = gtk_ui_manager_get_widget (m_UIManager, name.c_str ()),
+		GtkWidget *w = gtk_ui_manager_get_widget (m_UIManager->GetUIManager (), name.c_str ()),
 			*h = gtk_handle_box_new ();
+		g_object_set (G_OBJECT (h), "hexpand", true, NULL);
 		gtk_container_foreach (GTK_CONTAINER (w), (GtkCallback) register_item_cb, this);
 		gtk_toolbar_set_style (GTK_TOOLBAR (w), GTK_TOOLBAR_ICONS);
 		gtk_toolbar_set_show_arrow (GTK_TOOLBAR (w), false);
 		gtk_container_add (GTK_CONTAINER (h), w);
-		gtk_box_pack_start (m_ButtonsBox, h, true, true, 0);
+		gtk_container_add (GTK_CONTAINER (m_ButtonsGrid), h);
 		gtk_widget_show_all (h);
 	}
 }
 
-void Tools::SetUIManager (GtkUIManager *manager)
+void Tools::SetUIManager (gcugtk::UIManager *manager)
 {
 	m_UIManager = manager;
-	g_object_ref (m_UIManager);
 }
 
 void Tools::SetPage (Tool *tool, int i)
@@ -139,17 +136,18 @@ void Tools::RegisterTool (GtkWidget *w)
 {
 	char const *name = gtk_widget_get_name (w);
 	Application *App = dynamic_cast<Application*> (m_App);
-	if (strncmp (name, "Gtk", 3))
+	if (strncmp (name, "Gtk", 3)) {
 		App->SetToolItem (name, w);
-	Tool *tool = App->GetTool (name);
-	m_Pages[tool] = -1;
+		Tool *tool = App->GetTool (name);
+		m_Pages[tool] = -1;
+	}
 }
 
 void Tools::OnElementChanged (int Z)
 {
 	dynamic_cast<Application*> (m_App)->SetCurZ (Z);
 	// Hmm, we should find a better way to do the following, the path might change.
-	GtkWidget *w = gtk_ui_manager_get_widget (m_UIManager, "ui/AtomsToolbar/Atom1/Element");
+	GtkWidget *w = gtk_ui_manager_get_widget (m_UIManager->GetUIManager (), "ui/AtomsToolbar/Atom1/Element");
 	if (!w)
 		return;
 	GtkWidget* icon = gtk_tool_button_get_icon_widget (GTK_TOOL_BUTTON (w));
@@ -162,12 +160,6 @@ void Tools::OnElementChanged (int Z)
 		gtk_label_set_text (GTK_LABEL (icon), Element::Symbol (Z));
 }
 
-void Tools::Update (void)
-{
-	GtkWidget *w = glade_xml_get_widget (xml, "mendeleiev");
-	go_combo_box_set_tearable (GO_COMBO_BOX (w), TearableMendeleiev);
-}
-
 void Tools::OnHelp ()
 {
 	m_App->OnHelp (m_Tool->GetHelpTag ());
@@ -175,8 +167,7 @@ void Tools::OnHelp ()
 
 void Tools::SetElement (int Z)
 {
-	GtkComboPeriodic *w = reinterpret_cast<GtkComboPeriodic*> (glade_xml_get_widget (xml, "mendeleiev"));
-	gtk_combo_periodic_set_element (w, Z);
+	gcu_combo_periodic_set_element (m_Mendeleiev, Z);
 	OnElementChanged (Z);
 }
 
