@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * view.h 
+ * view.h
  *
- * Copyright (C) 2001-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -25,6 +25,8 @@
 #ifndef GCHEMPAINT_VIEW_H
 #define GCHEMPAINT_VIEW_H
 
+/*!\file*/
+
 #include <gcu/macros.h>
 #include <gccv/client.h>
 #include <list>
@@ -39,6 +41,10 @@ namespace gcu {
 	class Object;
 };
 
+namespace gcugtk {
+	class UIManager;
+}
+
 namespace gcp {
 
 class Atom;
@@ -69,7 +75,7 @@ The destructor.
 */
 	virtual ~View ();
 
-	//Interface	
+	//Interface
 public:
 /*!
 @return the canvas widget used for the view.
@@ -275,13 +281,20 @@ Changes the selection state of \a object if it owns an item and of all its desce
 */
 	void SetSelectionState (gcu::Object *object, int state);
 	// Signals
+	// there is no needd to document these since the documentation in gccv/client.h is appropriate.
 	bool OnButtonPressed (gccv::ItemClient *client, unsigned button, double x, double y, unsigned state);
 	bool OnButtonReleased (gccv::ItemClient *client, unsigned button, double x, double y, unsigned state);
 	bool OnDrag (gccv::ItemClient *client, double x, double y, unsigned state);
 	bool OnMotion (gccv::ItemClient *client, double x, double y, unsigned state);
 	bool OnLeaveNotify (unsigned state);
 
+/*!
+@return the WidgetData associated with the View widget.
+*/
 	WidgetData *GetData () {return m_pData;}
+
+	void GetVisibleArea (double &x0, double &y0, double &x1, double &y1);
+
 	//Implementation
 private:
 	WidgetData* m_pData;
@@ -294,11 +307,11 @@ private:
 	int m_width, m_height;
 	double m_lastx, m_lasty;
 	bool m_bEmbedded;
-	GtkUIManager *m_UIManager;
+	gcugtk::UIManager *m_UIManager;
 	bool m_Dragging;
 	gcu::Object *m_CurObject;
 	Atom *m_CurAtom;
-	
+
 
 /*!\fn GetBaseLineOffset()
 @return the vertical offset for algnment of an atomic symbol. This value is half the height of the "C" character.
