@@ -1,11 +1,11 @@
-/* 
+/*
  * GChemPaint library
  * window.cc
  *
- * Copyright (C) 2006-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2006-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -25,16 +25,104 @@
 #include "document.h"
 #include "newfiledlg.h"
 #include "window.h"
+#include "molecule.h"
 #include "about.h"
 #include "preferences.h"
 #include "theme.h"
 #include "view.h"
 #include "zoomdlg.h"
-#include <gcu/filechooser.h>
-#include <gcu/print-setup-dlg.h>
+#include <gcugtk/dialog.h>
+#include <gcugtk/filechooser.h>
+#include <gcugtk/print-setup-dlg.h>
+#include <gcugtk/ui-manager.h>
+#include <gcu/matrix.h>
+#include <gsf/gsf-input-memory.h>
 #include <glib/gi18n-lib.h>
 #include <string>
 
+using namespace gcu;
+
+namespace gcp {
+
+typedef void (*StringInputCB) (Target *obj, char const *str);
+
+class StringInput: public gcugtk::Dialog
+{
+public:
+	StringInput (Target *target, StringInputCB cb, char const *title);
+	virtual ~StringInput ();
+
+	bool Apply ();
+
+private:
+	Target *m_Target;
+	StringInputCB m_CB;
+};
+
+StringInput::StringInput (Target *target, StringInputCB cb, char const *title):
+	gcugtk::Dialog (target->GetApplication (), UIDIR"/stringinputdlg.ui", "string-input", GETTEXT_PACKAGE, target->GetDocument ()),
+	m_Target (target),
+	m_CB (cb)
+{
+	GtkWidget *w = GTK_WIDGET (gtk_builder_get_object (GetBuilder (), "string-input"));
+	gtk_window_set_title (GTK_WINDOW (w), title);
+	gtk_widget_show_all (w);
+}
+
+StringInput::~StringInput ()
+{
+}
+
+bool StringInput::Apply ()
+{
+	GtkEntry *entry = GTK_ENTRY (gtk_builder_get_object (GetBuilder (), "result"));
+	if (entry)
+		m_CB (m_Target, gtk_entry_get_text (entry));
+	return true;
+}
+
+class WindowPrivate {
+public:
+	static void ImportMolecule (G_GNUC_UNUSED GtkWidget* widget, gcp::Window* Win);
+	static void DoImportMol (Target *target, char const *str);
+};
+
+void WindowPrivate::ImportMolecule (G_GNUC_UNUSED GtkWidget* widget, gcp::Window* Win)
+{
+	new StringInput (Win, &DoImportMol, _("Import moleculefrom InChI or SMILES"));
+}
+
+void WindowPrivate::DoImportMol (Target *target, char const *str)
+{
+	if (!str || !*str)
+		return;
+	Application *app = target->GetApplication ();
+	Document *doc = target->GetDocument ();
+	GsfInput *input = gsf_input_memory_new (reinterpret_cast < guint8 const * > (str), strlen (str), false);
+	char *cml = app->ConvertToCML (input, ((!strncmp (str, "InChI=", 6))? "inchi": "smi"), "-c --gen2D");
+	g_object_unref (input);
+	if (!cml) // TODO: add an error message handler
+		return;
+	input = gsf_input_memory_new (reinterpret_cast < guint8 const * > (cml), strlen (cml), true);
+	app->Load (input, "chemical/x-cml", target->GetDocument (), NULL);
+	std::set < gcu::Object * > objs = static_cast < gcu::Document * > (doc)->GetNewObjects ();
+	doc->Loaded ();
+	Molecule *mol = static_cast < Molecule * > ((*objs.begin ())->GetMolecule ());
+	// scale so that the mean bond length is correct
+	double l = mol->GetMeanBondLength (), l0 = doc->GetTheme ()->GetBondLength (), x0, y0, x1, y1;
+	l0 /= l;
+	Matrix2D m (l0, 0., 0., l0);
+	mol->Transform2D (m, 0., 0.);
+	// move to view center
+	doc->GetView ()->GetVisibleArea (x0, y0, x1, y1);
+	mol->Move ((x0 + x1) / 2., (y0 + y1) / 2.);
+	// show the molecule
+	doc->GetView ()->Update (mol);
+	// mark the document as unsaved
+	doc->SetDirty ();
+	g_object_unref (input);
+}
+
 static void on_destroy (G_GNUC_UNUSED GtkWidget* widget, gcp::Window* Win)
 {
 	Win->GetDocument ()->GetView ()->PrepareUnselect ();
@@ -349,6 +437,8 @@ static GtkActionEntry entries[] = {
 		  { "Zoom", NULL, N_("_Zoom to...%"), "<control>M",
 			  N_("Open Zoom Dialog Box"), G_CALLBACK (on_zoom) },
   { "ToolsMenu", NULL, N_("_Tools"), NULL, NULL, NULL },
+	  { "ImportMol", NULL, N_("_Import molecule"), NULL,
+		  N_("Import a molecule either from InChI or SMILES"), G_CALLBACK (WindowPrivate::ImportMolecule) },
   { "WindowsMenu", NULL, N_("_Windows"), NULL, NULL, NULL },
   { "HelpMenu", NULL, N_("_Help"), NULL, NULL, NULL },
 	  { "Help", GTK_STOCK_HELP, N_("_Contents"), "F1",
@@ -420,6 +510,7 @@ static const char *ui_description =
 "    </menu>"
 "    <menu action='ToolsMenu'>"
 "	   <placeholder name='tools1'/>"
+"	   <menuitem action='ImportMol'/>"
 "      <separator name='tools-sep1'/>"
 "      <placeholder name='tools2'/>"
 "    </menu>"
@@ -446,14 +537,10 @@ static const char *ui_description =
 "  </toolbar>"
 "</ui>";
 
-using namespace gcu;
-
-namespace gcp {
-
 Window::Window (gcp::Application *App, char const *Theme, char const *extra_ui) throw (std::runtime_error):
 	Target (App)
 {
-	GtkWidget *vbox;
+	GtkWidget *grid;
 	GtkWidget *bar;
 	GtkWindow *window;
 	GtkActionGroup *action_group;
@@ -466,28 +553,29 @@ Window::Window (gcp::Application *App, char const *Theme, char const *extra_ui)
 	g_object_set_data (G_OBJECT (window), "gcp-role", (void*) 1);
 	g_signal_connect (G_OBJECT (window), "destroy", G_CALLBACK (on_destroy), this);
 	g_signal_connect (G_OBJECT (window), "delete-event", G_CALLBACK (on_delete_event), this);
-	vbox = gtk_vbox_new (FALSE, 0);
-	gtk_container_add (GTK_CONTAINER (window), vbox);
+	grid = gtk_grid_new ();
+	g_object_set (G_OBJECT (grid), "orientation", GTK_ORIENTATION_VERTICAL, NULL);
+	gtk_container_add (GTK_CONTAINER (window), grid);
 	action_group = gtk_action_group_new ("MenuActions");
 	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
 	gtk_action_group_add_actions (action_group, entries, G_N_ELEMENTS (entries), this);
 	gtk_action_group_add_toggle_actions (action_group, toggle_entries, G_N_ELEMENTS (toggle_entries), this);
 
-	m_UIManager = gtk_ui_manager_new ();
-	g_object_connect (m_UIManager,
+	m_UIManager = new gcugtk::UIManager (gtk_ui_manager_new ());
+	g_object_connect (m_UIManager->GetUIManager (),
 		"signal::connect_proxy",    G_CALLBACK (on_connect_proxy), this,
 		"signal::disconnect_proxy", G_CALLBACK (on_disconnect_proxy), this,
 		NULL);
-	gtk_ui_manager_insert_action_group (m_UIManager, action_group, 0);
+	gtk_ui_manager_insert_action_group (m_UIManager->GetUIManager (), action_group, 0);
 	g_object_unref (action_group);
-	
+
 	error = NULL;
-	if (!gtk_ui_manager_add_ui_from_string (m_UIManager, ui_description, -1, &error)) {
+	if (!gtk_ui_manager_add_ui_from_string (m_UIManager->GetUIManager (), ui_description, -1, &error)) {
 		std::string what = std::string ("building menus failed: ") + error->message;
 		g_error_free (error);
 		throw std::runtime_error (what);
 	}
-	if (extra_ui && !gtk_ui_manager_add_ui_from_string (m_UIManager, extra_ui, -1, &error)) {
+	if (extra_ui && !gtk_ui_manager_add_ui_from_string (m_UIManager->GetUIManager (), extra_ui, -1, &error)) {
 		g_message ("building menus failed: %s", error->message);
 		g_error_free (error);
 	}
@@ -495,25 +583,25 @@ Window::Window (gcp::Application *App, char const *Theme, char const *extra_ui)
 	//  now add entries registered by plugins.
 	App->BuildMenu (m_UIManager);
 
-	accel_group = gtk_ui_manager_get_accel_group (m_UIManager);
+	accel_group = gtk_ui_manager_get_accel_group (m_UIManager->GetUIManager ());
 	gtk_window_add_accel_group (window, accel_group);
 
 	switch (App->GetDefaultWindowState ()) {
-	case MaximizedWindowState:
+	case gcugtk::MaximizedWindowState:
 		gtk_window_maximize (window);
 		break;
-	case MinimizedWindowState:
+	case gcugtk::MinimizedWindowState:
 		gtk_window_iconify (window);
 		break;
-	case FullScreenWindowState:
+	case gcugtk::FullScreenWindowState:
 		gtk_window_fullscreen (window);
-		gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (gtk_ui_manager_get_action (m_UIManager, "/MainMenu/ViewMenu/FullScreen")), true);
+		gtk_toggle_action_set_active (GTK_TOGGLE_ACTION (gtk_ui_manager_get_action (m_UIManager->GetUIManager (), "/MainMenu/ViewMenu/FullScreen")), true);
 		break;
 	default:
 		break;
 	}
 
-	GtkWidget *menu = gtk_ui_manager_get_widget (m_UIManager, "/MainMenu/FileMenu/Open");
+	GtkWidget *menu = gtk_ui_manager_get_widget (m_UIManager->GetUIManager (), "/MainMenu/FileMenu/Open");
 	GtkWidget *w = gtk_recent_chooser_menu_new_for_manager (App->GetRecentManager ());
 	gtk_recent_chooser_set_sort_type (GTK_RECENT_CHOOSER (w), GTK_RECENT_SORT_MRU);
 	GtkRecentFilter *filter = gtk_recent_filter_new ();
@@ -528,10 +616,10 @@ Window::Window (gcp::Application *App, char const *Theme, char const *extra_ui)
 	gtk_widget_show_all (item);
 	gtk_menu_shell_insert (GTK_MENU_SHELL (gtk_widget_get_parent (menu)), item, 3);
 
-	bar = gtk_ui_manager_get_widget (m_UIManager, "/MainMenu");
-	gtk_box_pack_start (GTK_BOX (vbox), bar, false, false, 0);
-	bar = gtk_ui_manager_get_widget (m_UIManager, "/MainToolbar");
-	gtk_box_pack_start (GTK_BOX (vbox), bar, false, false, 0);
+	bar = gtk_ui_manager_get_widget (m_UIManager->GetUIManager (), "/MainMenu");
+	gtk_container_add (GTK_CONTAINER (grid), bar);
+	bar = gtk_ui_manager_get_widget (m_UIManager->GetUIManager (), "/MainToolbar");
+	gtk_container_add (GTK_CONTAINER (grid), bar);
 	m_Document = new Document (App, true, this);
 	if (Theme)
 		m_Document->SetTheme (TheThemeManager.GetTheme (Theme));
@@ -543,26 +631,26 @@ Window::Window (gcp::Application *App, char const *Theme, char const *extra_ui)
 	gtk_scrolled_window_add_with_viewport (scroll, w);
 	gtk_widget_set_size_request (GTK_WIDGET (scroll), 408, 308);
 	gtk_widget_show (GTK_WIDGET (scroll));
-	gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (scroll), true, true, 0);
+	gtk_container_add (GTK_CONTAINER (grid), GTK_WIDGET (scroll));
 	m_Bar = gtk_statusbar_new ();
 	m_statusId = gtk_statusbar_get_context_id (GTK_STATUSBAR (m_Bar), "status");
 	gtk_statusbar_push (GTK_STATUSBAR (m_Bar), m_statusId, _("Ready"));
 	m_MessageId = 0;
-	gtk_box_pack_start (GTK_BOX (vbox), m_Bar, false, false, 0);
-		
-	g_signal_connect(GTK_OBJECT(window), "key_press_event", (GCallback)on_key_press, this);
-	g_signal_connect(GTK_OBJECT(window), "key_release_event", (GCallback)on_key_release, this);
+	gtk_container_add (GTK_CONTAINER (grid), m_Bar);
 
-	gtk_widget_set_sensitive (gtk_ui_manager_get_widget (m_UIManager, "/MainMenu/EditMenu/Copy"), false);
-	gtk_widget_set_sensitive (gtk_ui_manager_get_widget (m_UIManager, "/MainMenu/EditMenu/Cut"), false);
-	gtk_widget_set_sensitive (gtk_ui_manager_get_widget (m_UIManager, "/MainMenu/EditMenu/Erase"), false);
+	g_signal_connect (G_OBJECT(window), "key_press_event", (GCallback)on_key_press, this);
+	g_signal_connect (G_OBJECT(window), "key_release_event", (GCallback)on_key_release, this);
+
+	gtk_widget_set_sensitive (gtk_ui_manager_get_widget (m_UIManager->GetUIManager (), "/MainMenu/EditMenu/Copy"), false);
+	gtk_widget_set_sensitive (gtk_ui_manager_get_widget (m_UIManager->GetUIManager (), "/MainMenu/EditMenu/Cut"), false);
+	gtk_widget_set_sensitive (gtk_ui_manager_get_widget (m_UIManager->GetUIManager (), "/MainMenu/EditMenu/Erase"), false);
 	gtk_widget_show_all (GTK_WIDGET (window));
 	App->SetActiveDocument (m_Document);
 }
 
 Window::~Window ()
 {
-	g_object_unref (m_UIManager);
+	delete m_UIManager;
 }
 
 void Window::OnFileNew()
@@ -580,7 +668,7 @@ void Window::OnSave()
 
 void Window::OnFileOpen()
 {
-	FileChooser (m_Application, false, m_Application->GetSupportedMimeTypes (), (!m_Document->HasChildren () && !m_Document->GetDirty ())? m_Document: NULL);
+	gcugtk::FileChooser (m_Application, false, m_Application->GetSupportedMimeTypes (), (!m_Document->HasChildren () && !m_Document->GetDirty ())? m_Document: NULL);
 }
 
 void Window::OnProperties()
@@ -652,7 +740,7 @@ void Window::Zoom (double zoom)
 	else {
 		Dialog *pDialog = m_Document->GetDialog ("Zoom");
 		if (pDialog)
-			gtk_window_present (pDialog->GetWindow ()); 
+			pDialog->Present ();
 		else
 			new ZoomDlg (m_Document);
 	}
@@ -720,7 +808,7 @@ char const *Window::GetDefaultTitle ()
 
 void Window::ActivateActionWidget (char const *path, bool activate)
 {
-	GtkWidget *w = gtk_ui_manager_get_widget (m_UIManager, path);
+	GtkWidget *w = gtk_ui_manager_get_widget (m_UIManager->GetUIManager (), path);
 	if (w)
 		gtk_widget_set_sensitive (w, activate);
 }
@@ -750,7 +838,7 @@ bool Window::VerifySaved ()
 
 void Window::OnPageSetup ()
 {
-	new PrintSetupDlg (m_Application, m_Document);
+	new gcugtk::PrintSetupDlg (m_Application, m_Document);
 }
 
 } // namespace gcp
