@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GCrystal library
  * application.cc
  *
- * Copyright (C) 2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2010-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -27,12 +27,12 @@
 
 namespace gcr {
 
-Application::Application (): gcu::Application ("gcrystal")
+Application::Application (): gcugtk::Application ("gcrystal")
 {
 }
 
 Application::~Application ()
 {
 }
-	
+
 }	//	namespace gcr
