@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemistry Utils
- * gcr/view.h 
+ * gcr/view.h
  *
  * Copyright (C) 2002-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -30,13 +30,13 @@
 #include <gcugtk/glview.h>
 #include <list>
 #include <map>
-#include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 
 /*!\file*/
 namespace gcr
 {
 class Document;
-	
+
 /*!\class View gcr/view.h
 The class representing a view of the model. Each document
 might have several views.
