@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemistry Utils
  * gcu/application.h
  *
- * Copyright (C) 2005-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -42,28 +42,12 @@ class Dialog;
 struct option_data;
 class TypeDesc;
 class CmdContext;
+class UIManager;
 
-/*!
-Window states
-*/
-typedef enum {
-/*!
-Normal window.
-*/
-	NormalWindowState,
-/*!
-Maximized window.
-*/
-	MaximizedWindowState,
-/*!
-Minimized window.
-*/
-	MinimizedWindowState,
-/*!
-Full screen window.
-*/
-	FullScreenWindowState
-} WindowState;
+typedef struct {
+	std::string name;
+	std::string uri;
+} Database;
 
 #define GCU_CONF_DIR "gchemutils"
 
@@ -74,12 +58,11 @@ class Application: virtual public DialogOwner
 {
 friend class Document;
 friend class Dialog;
-friend class ApplicationPrivate;
 public:
 /*!
 @param name the name of the application.
 @param datadir where data for the application are stored.
-@param help_name the name to use for the help file (with .xml extension). 
+@param help_name the name to use for the help file (with .xml extension).
 If NULL, the name parameter is used.
 @param icon_name the name to use for the default icon of all windows. If NULL,
 the help_name or name parameters will be used.
@@ -109,7 +92,7 @@ helpfilename\#myapp-mytag.
 /*!
 @return the name of the application. Mostly useful to set the icon name of a new window.
 */
-	std::string &GetName () {return Name;}
+	std::string const &GetName () const {return Name;}
 
 /*!
 @return a GtkWindow if any. Should be overloaded by children classes.
@@ -126,7 +109,7 @@ helpfilename\#myapp-mytag.
 Called by the FileChooser when a file name has been selected. This method does
 nothing in the parent class and must be implemented in children classes
 if they use the FileChooser.
-	
+
 @return true if no error occured.
 */
 	virtual bool FileProcess (G_GNUC_UNUSED const gchar* filename, G_GNUC_UNUSED const gchar* mime_type, G_GNUC_UNUSED bool bSave, G_GNUC_UNUSED GtkWindow *window, G_GNUC_UNUSED Document *pDoc = NULL)
@@ -182,18 +165,6 @@ Attempts to open the \#gchemutils channel at irc.gimp.net.
 */
 	void OnLiveAssistance ();
 
-/*!
-@return a GtkWidget for managing pixmap resolution when saving as image. This widget is
-intended to be added to a GtkFileChooserDialog.
-*/
-	GtkWidget *GetImageResolutionWidget ();
-
-/*!
-@return a GtkWidget for managing pixmap width and height when saving as image. This
-widget is intended to be added to a GtkFileChooserDialog.
-*/
-	GtkWidget *GetImageSizeWidget ();
-
 /*!
 @return a std::map of the supported pixbuf formats. Keys are the mime type names.
 */
@@ -217,21 +188,44 @@ is not supported by GdkPixbuf.
 
 This method loads a document using the appropriate gcu::Loader class
 instance.
-@return true if no error occurred.
+@return the found \a ContentType ot ContentTypeUnknown if an error occured.
 */
-	ContentType Load (std::string const &uri, const gchar *mime_type, Document* Doc);
+	ContentType Load (std::string const &uri, const char *mime_type, Document* Doc, const char *options = NULL);
+
+/*!
+@param input a GsfInput.
+@param mime_type the mime type of the document.
+@param Doc the document instance which will contain the loaded data.
+
+This method loads a document using the appropriate gcu::Loader class
+instance.
+@return the found \a ContentType ot ContentTypeUnknown if an error occured.
+*/
+	ContentType Load (GsfInput *input, const char *mime_type, Document* Doc, const char *options = NULL);
 
 /*!
 @param uri the uri to which the document should be saved.
 @param mime_type the mime type of the document.
-@param Doc the document instance which contains the data to be saved.
+@param Obj the object instance which contains the data to be saved.
 @param type the type of the data to be saved (see gcu::ContentType).
 
 This method saves the document using the appropriate gcu::Loader class
 instance.
 @return true if no error occurred.
 */
-	bool Save (std::string const &uri, const gchar *mime_type, Document const *Doc, ContentType type);
+	bool Save (std::string const &uri, const char *mime_type, Object const *Obj, ContentType type, const char *options = NULL);
+
+/*!
+@param output a GsfOutput.
+@param mime_type the mime type of the document.
+@param Obj the object instance which contains the data to be saved.
+@param type the type of the data to be saved (see gcu::ContentType).
+
+This method saves the document using the appropriate gcu::Loader class
+instance using \a output as target.
+@return true if no error occurred.
+*/
+	bool Save (GsfOutput *output, const char *mime_type, Object const *Obj, ContentType type, const char *options = NULL);
 
 /*!
 Virtual method used to create documents. Default behavior does nothing and returns NULL.
@@ -268,10 +262,6 @@ just after creating the application and before parsing options.
 */
 	void AddOptions (GOptionContext *context);
 /*!
-@return the default WindowState for the application. New window should use this setting.
-*/
-	static WindowState GetDefaultWindowState () {return DefaultWindowState;}
-/*!
 @return a dummy Application instance which might be used when there is no other
 Application available.
 */
@@ -302,18 +292,6 @@ It will also be given a default Id.
 @return a pointer to the newly created Object or NULL if the Object could not be created.
 */
 	Object* CreateObject (const std::string& TypeName, Object* parent = NULL);
-
-/*!
-@param UIManager the GtkUIManager to populate.
-@param object the Object on which occured the mouse click.
-@param x x coordinate of the mouse click.
-@param y y coordinate of the mouse click.
-
-This method is called to build a contextual menu for the object. It is called by Object::BuildContextualMenu, so
-it should not be necessary to call it directly.
-@return true if something is added to the UIManager, false otherwise.
-*/
-	bool BuildObjectContextualMenu (Object *target, GtkUIManager *UIManager, Object *object, double x, double y);
 /*!
 @param type1 the TypeId of the first class in the rule
 @param rule the new rule value
@@ -363,11 +341,16 @@ the class seems possible.
 	const std::string& GetCreationLabel (TypeId Id);
 
 /*!
-@param TypeName the name of a class
+@param uim the UIManager to populate.
+@param object the Object on which occured the mouse click.
+@param x x coordinate of the mouse click.
+@param y y coordinate of the mouse click.
 
-@return the string defined by SetCreationLabel.
+This method is called to build a contextual menu for the object. It is called by Object::BuildContextualMenu, so
+it should not be necessary to call it directly.
+@return true if something is added to the UIManager, false otherwise.
 */
-	const std::string& GetCreationLabel (const std::string& TypeName);
+	bool BuildObjectContextualMenu (Object *target, UIManager *uim, Object *object, double x, double y);
 
 /*!
 @param Id the TypeId of the Object derived class
@@ -377,21 +360,58 @@ adds a callback for modifying the contextual menu of objects of type Id.
 */
 	void AddMenuCallback (TypeId Id, BuildMenuCb cb);
 
+/*!
+@param TypeName the name of a class
+
+@return the string defined by SetCreationLabel.
+*/
+	const std::string& GetCreationLabel (const std::string& TypeName);
+
 	TypeDesc const *GetTypeDescription (TypeId Id);
 	CmdContext *GetCmdContext ();
 
-protected:
 
 /*!
-This method is called by the framework when all the documents have been removed from
-the set of opened documents. The default behavior is to call gtk_main_quit and exit
-the program. Derived class might overide this method to change this.
+@param input a source GsfInput.
+@param mime_type the mime type of the document.
+@param options options to pass to OpenBabel.
+
+This method converts the source to CML.
+@return the converted text as a newly allocate string or NULL.
 */
-	virtual void NoMoreDocsEvent () {gtk_main_quit ();}
+	char* ConvertToCML (std::string const &uri, const char *mime_type, const char *options = NULL);
+	char* ConvertToCML (GsfInput *input, const char *mime_type, const char *options = NULL);
+
+/*!
+@param cml: the CML string to convert.
+@param uri the uri of the document to which the document will be saved.
+@param mime_type the mime type of the document.
+@param options options to pass to OpenBabel.
+
+This method converts CML to a target.
+*/
+	void ConvertFromCML (const char *cml, std::string const &uri, const char *mime_type, const char *options = NULL);
+
+/*!
+@param cml: the CML string to convert.
+@param output a target GsfOutput.
+@param mime_type the mime type of the document.
+@param options options to pass to OpenBabel.
+
+This method converts CML to a target.
+*/
+	void ConvertFromCML (const char *cml, GsfOutput *output, const char *mime_type, const char *options = NULL);
+	std::list < Database > const &GetDatabases (char const *classname) {return m_Databases[classname];}
+
+protected:
+	void RegisterBabelType (const char *mime_type, const char *type);
+	virtual void CreateDefaultCmdContext () {}
 
 private:
 	void AddDocument (Document *Doc) {m_Docs.insert (Doc);}
 	void RemoveDocument (Document *Doc);
+	int OpenBabelSocket ();
+	char const *MimeToBabelType (char const *mime_type);
 
 private:
 	std::string Name;
@@ -401,11 +421,18 @@ private:
 	std::string CurDir;
 	std::string IconName;
 	static GOConfNode *m_ConfDir;
-	std::list<option_data> m_Options;
-	static WindowState DefaultWindowState;
-	std::map<TypeId, TypeDesc> m_Types;
+	std::list <option_data> m_Options;
+	std::map <TypeId, TypeDesc> m_Types;
+	std::map <std::string, std::string> m_BabelTypes;
 
 protected:
+
+/*!
+This method is called by the framework when all the documents have been removed from
+the set of opened documents. The default behavior is to do nothing
+Derived class might overide this method to change this.
+*/
+	virtual void NoMoreDocsEvent () {}
 /*!
 std::map of the supported pixbuf formats. Keys are the mime type names.
 */
@@ -413,6 +440,8 @@ std::map of the supported pixbuf formats. Keys are the mime type names.
 
 	CmdContext *m_CmdContext;
 
+private:
+	std::map < std::string, std::list <Database> >m_Databases;
 /*!\var m_Docs
 The currently opened documents.
 */
@@ -478,10 +507,6 @@ Sets the transparency of the exported image when possible.
 @return whether exported image have a transparent background as a reference.
 */
 GCU_PROP (bool, TransparentBackground)
-/*!\fn GetRecentManager()
-@return the GtkRecentFileManager attached to the application.
-*/
-GCU_RO_PROP (GtkRecentManager*, RecentManager)
 };
 
 }	// namespace gcu
