@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemistry Utils
  * gcu/chem3ddoc.cc
  *
- * Copyright (C) 2006-2009 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2006-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -34,17 +34,18 @@
 #include "vector.h"
 #include <gcu/chemistry.h>
 #include <gcu/element.h>
-#include <openbabel/obconversion.h>
+#include <gsf/gsf-input-memory.h>
+#include <goffice/goffice.h>
 #include <gio/gio.h>
 #include <GL/gl.h>
 #include <libintl.h>
 #include <clocale>
 #include <fstream>
+#include <iostream>
 #include <ostream>
 #include <sstream>
 #include <cstring>
 
-using namespace OpenBabel;
 using namespace std;
 
 namespace gcu
@@ -52,20 +53,21 @@ namespace gcu
 
 Chem3dDoc::Chem3dDoc (): GLDocument (Application::GetDefaultApplication ())
 {
-	m_View = new GLView (this);
+	m_View = CreateView ();
 	m_Display3D = BALL_AND_STICK;
 	m_Mol = NULL;
 }
 
 Chem3dDoc::Chem3dDoc (Application *App, GLView *View): GLDocument (App)
 {
-	m_View = (View)? View: new GLView (this);
+	m_View = (View)? View: CreateView ();
 	m_Display3D = BALL_AND_STICK;
 	m_Mol = NULL;
 }
 
 Chem3dDoc::~Chem3dDoc ()
 {
+	delete m_View;
 }
 
 static Object* CreateAtom ()
@@ -82,6 +84,7 @@ static Object* CreateMolecule ()
 {
 	return new Molecule ();
 }
+
 void Chem3dDoc::Load (char const *uri, char const *mime_type)
 {
 	GVfs *vfs = g_vfs_get_default ();
@@ -100,7 +103,13 @@ void Chem3dDoc::Load (char const *uri, char const *mime_type)
 		return;
 	}
 	if (!mime_type)
-		mime_type = g_file_info_get_content_type(info);
+		mime_type = g_file_info_get_content_type (info);
+	g_object_unref (info);
+	if (!mime_type) {
+		// should not happen
+		g_object_unref (file);
+		return;
+	}
 	// try using the loader mechanism
 	Application *app = GetApp ();
 	Object *obj = app->CreateObject ("atom", this);
@@ -117,7 +126,72 @@ void Chem3dDoc::Load (char const *uri, char const *mime_type)
 	ContentType type = app->Load (filename, mime_type, this);
 	Loaded ();
 	if (type == ContentType3D) {
-		g_object_unref (file);
+		// center the scene around 0,0,0
+		std::map<std::string, Object*>::iterator it;
+		obj =  GetFirstChild (it);
+		while (obj) {
+			m_Mol = dynamic_cast <Molecule *> (obj);
+			if (m_Mol)
+				break;
+			obj = GetNextChild (it);
+		}
+		// FIXME: we show only one molecule
+		double x0, y0, z0;
+		x0 = y0 = z0 = 0.0;
+		std::list <Atom *>::const_iterator i;
+		Atom const *atom = m_Mol->GetFirstAtom (i);
+		while (atom) {
+			x0 += atom->x ();
+			y0 += atom->y ();
+			z0 += atom->z ();
+			atom = m_Mol->GetNextAtom (i);
+		}
+		m_Mol->Move (-x0 / m_Mol->GetAtomsNumber (), -y0 / m_Mol->GetAtomsNumber (), -z0 / m_Mol->GetAtomsNumber ());
+		char const *title = m_Mol->GetName ();
+		if (title)
+			SetTitle (title);
+		else {
+			char *fn = g_file_get_basename (file);
+			SetTitle (fn);
+			g_free (fn);
+		}
+		m_View->Update ();
+	} else if (type != ContentTypeUnknown) {
+		Clear ();
+		// TODO: process the error (display a message at least or open with an appropriate application)
+	}
+	g_object_unref (file);
+}
+
+void Chem3dDoc::LoadData (char const *data, char const *mime_type, size_t size)
+{
+	bool need_free = false;
+	if (!mime_type) {
+		mime_type = go_get_mime_type_for_data (data, size);
+		need_free = true;
+	}
+	if (!mime_type) {
+		// should not happen
+		return;
+	}
+	if (size == 0)
+		size = strlen (data);
+	GsfInput *input = gsf_input_memory_new (reinterpret_cast <guint8 const *> (data), size, false);
+	// try using the loader mechanism
+	Application *app = GetApp ();
+	Object *obj = app->CreateObject ("atom", this);
+	if (obj)
+		delete obj;
+	else {
+		gcu::Loader::Init (app); // can be called many times
+		app->AddType ("atom", CreateAtom, AtomType);
+		app->AddType ("bond", CreateBond, BondType);
+		app->AddType ("molecule", CreateMolecule, MoleculeType);
+	}
+	Clear ();
+	ContentType type = app->Load (input, mime_type, this);
+	Loaded ();
+	if (type == ContentType3D) {
 		// center the scene around 0,0,0
 		std::map<std::string, Object*>::iterator it;
 		obj =  GetFirstChild (it);
@@ -143,99 +217,13 @@ void Chem3dDoc::Load (char const *uri, char const *mime_type)
 		if (title)
 			SetTitle (title);
 		m_View->Update ();
-		return;
 	} else if (type != ContentTypeUnknown) {
 		Clear ();
-		g_object_unref (file);
-		// TODO: process the error (display a message at least or open with an appropriate application)
-		return;
+		// TODO: process the error
 	}
-	gsize size = g_file_info_get_size (info);
-	g_object_unref (info);
-	GInputStream *input = G_INPUT_STREAM (g_file_read (file, NULL, &error));
-	if (error) {
-		g_message ("GIO could not create the stream: %s", error->message);
-		g_error_free (error);
-		g_object_unref (file);
-		error = NULL;
-		return;
-	}
-	gchar *buf = new gchar[size + 1];
-	gsize n = g_input_stream_read (input, buf, size, NULL, &error);
-	if (error) {
-		g_message ("GIO could not read the file: %s", error->message);
-		g_error_free (error);
-		delete [] buf;
-		g_object_unref (input);
-		g_object_unref (file);
-		error = NULL;
-		return;
-	}
-	buf[size] = 0;
-	m_Title.clear ();
-	m_Mol = new Molecule ();
-	AddChild (m_Mol);
-	if (n == size) {
-		LoadData (buf, mime_type);
-		if (m_App) {
-			char *dirname = g_path_get_dirname (uri);
-			m_App->SetCurDir (dirname);
-			g_free (dirname);
-		}
-		if (m_Title.length () == 0) {
-			char *name = g_path_get_basename (uri);
-			SetTitle (name);
-			g_free (name);
-		}
-	}
-	delete [] buf;
+	if (need_free)
+		g_free (const_cast <char *> (mime_type));
 	g_object_unref (input);
-	g_object_unref (file);
-}
-
-void Chem3dDoc::LoadData (char const *data, char const *mime_type)
-{
-	istringstream is (data);
-	OBConversion Conv;
-	OBFormat* pInFormat = Conv.FormatFromMIME (mime_type);
-	OBMol Molecule;
-	if (pInFormat) {
-		Conv.SetInAndOutFormats (pInFormat, pInFormat);
-		Conv.Read (&Molecule,&is);
-		m_Empty = Molecule.NumAtoms () == 0;
-	}
-	m_Mol->Clear ();
-	// center the molecule around 0,0,0
-	std::vector < OBNodeBase * >::iterator i;
-	OBAtom* atom = Molecule.BeginAtom (i);
-	std::map <OBAtom *, Atom *> atomMap;
-	gdouble x0, y0, z0;
-	x0 = y0 = z0 = 0.0;
-	while (atom) {
-		x0 += atom->GetX ();
-		y0 += atom->GetY ();
-		z0 += atom->GetZ ();
-		atom = Molecule.NextAtom (i);
-	}
-	x0 /= Molecule.NumAtoms ();
-	y0 /= Molecule.NumAtoms ();
-	z0 /= Molecule.NumAtoms ();
-	vector3 v(-x0, -y0, -z0);
-	atom = Molecule.BeginAtom (i);
-	while (atom) {
-		atom->SetVector ((atom->GetVector () + v) * 100);
-		atomMap[atom] = new Atom (atom->GetAtomicNum (), atom->GetX (), atom->GetY (), atom->GetZ ());
-		m_Mol->AddAtom (atomMap[atom]);
-		atom = Molecule.NextAtom (i);
-	}
-	std::vector < OBEdgeBase * >::iterator j;
-	OBBond* bond = Molecule.BeginBond (j);
-	while (bond) {
-		m_Mol->AddBond (new Bond (atomMap[bond->GetBeginAtom ()], atomMap[bond->GetEndAtom ()], bond->GetBondOrder ()));
-		bond = Molecule.NextBond (j);
-	}
-	SetTitle (Molecule.GetTitle());
-	m_View->Update ();
 }
 
 struct VrmlBond {
@@ -267,7 +255,7 @@ void Chem3dDoc::OnExportVRML (string const &filename)
 	}
 
 	file << "#VRML V2.0 utf8" << endl;
-	
+
 	x0 = y0 = z0 = 0.0;
 	std::list <Atom *>::const_iterator i;
 	Atom const *atom = m_Mol->GetFirstAtom (i);
@@ -283,6 +271,12 @@ void Chem3dDoc::OnExportVRML (string const &filename)
 	z0 /= m_Mol->GetAtomsNumber ();
 
 	//Create prototypes for atoms
+	GcuAtomicRadius radius;
+	radius.type = GCU_VAN_DER_WAALS;
+	radius.charge = 0;
+	radius.cn = -1;
+	radius.spin = GCU_N_A_SPIN;
+	radius.scale = NULL;
 	for (atom = m_Mol->GetFirstAtom (i); atom; atom = m_Mol->GetNextAtom (i)) {
 		Z = atom->GetZ ();
 		if (!Z)
@@ -290,7 +284,9 @@ void Chem3dDoc::OnExportVRML (string const &filename)
 		symbol = Element::Symbol (Z);
 		if (AtomsMap[symbol].l.empty()) {
 			AtomsMap[symbol].n = n;
-			R = etab.GetVdwRad (Z);
+			radius.Z = Z;
+			gcu_element_get_radius (&radius);
+			R = radius.value.value / 100; // convert from pm to Angstrom (supposing that the unit is actually pm).
 			if (m_Display3D == BALL_AND_STICK)
 				R *= 0.2;
 			color = gcu_element_get_default_color (Z);
@@ -521,4 +517,9 @@ void Chem3dDoc::Clear ()
 	m_Mol = NULL;
 }
 
+GLView *Chem3dDoc::CreateView ()
+{
+	return NULL;
+}
+
 }	//	namespace gcu
