@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemistry Utils
- * molecule.cc 
+ * molecule.cc
  *
  * Copyright (C) 2001-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -130,9 +130,8 @@ void Molecule::UpdateCycles (Bond* pBond)	//FIXME: function not totally implemen
 	delete pChain;
 }
 
-void Molecule::UpdateCycles ()
+void Molecule::ClearCycles ()
 {
-	Lock (true);
 	std::list<Bond*>::iterator n, end = m_Bonds.end ();
 	for (n = m_Bonds.begin (); n != end; n++)
 		(*n)->RemoveAllCycles ();
@@ -140,6 +139,12 @@ void Molecule::UpdateCycles ()
 		delete m_Cycles.front ();
 		m_Cycles.pop_front ();
 	}
+}
+
+void Molecule::UpdateCycles ()
+{
+	Lock (true);
+	ClearCycles ();
 	if (!m_Atoms.empty()) {
 		std::list<Atom*>::iterator i = m_Atoms.begin (), end = m_Atoms.end ();
 		i++;
@@ -222,7 +227,7 @@ Molecule *Molecule::MoleculeFromFormula (Document *Doc, Formula const &formula,
 			// destroy the molecule
 			mol->SetParent (NULL);
 			delete mol;
-			return NULL;			
+			return NULL;
 		}
 		if ((fatom = dynamic_cast <FormulaAtom *> (*i))) {
 			valence = fatom->GetValence ();
