@@ -1,10 +1,10 @@
-/* 
+/*
  * Gnome Chemisty Utils
- * chem-viewer.c 
+ * chem-viewer.c
  *
  * Copyright (C) 2005-2008 Jean Bréfort <jean.brefort@normalesup.org>
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -21,9 +21,9 @@
 
 #include "config.h"
 #include <gcu/element.h>
-#include <gcu/gcuchem3dviewer.h>
-#include <gcu/gcucrystalviewer.h>
-#include <gcu/gcuspectrumviewer.h>
+#include <gcugtk/gcuchem3dviewer.h>
+#include <gcr/gcrcrystalviewer.h>
+#include <gcugtk/gcuspectrumviewer.h>
 #include <gcu/chem3ddoc.h>
 #include <gcu/loader.h>
 #include <gcp/application.h>
@@ -36,8 +36,8 @@
 #include <goffice/app/go-plugin.h>
 #include <goffice/app/go-plugin-loader-module.h>
 #include <gdk/gdkx.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkplug.h>
+#include <gtk/gtk.h>
+#include <gtk/gtkx.h>
 #include <iostream>
 #include <fstream>
 #include <sstream>
@@ -84,11 +84,9 @@ private:
 	XID Xid;
 	string Filename, MimeType;
 	GtkWidget *Plug, *Viewer;
-	GdkWindow *Parent;
 	gcp::Document *Doc;
 	map<string, string> Params;
 	MozPaintApp *gcpApp;
-	gcu::Application *App;
 	bool Loaded;
 };
 
@@ -101,7 +99,6 @@ ChemComp::ChemComp (void* instance, string& mime_type)
 	Doc = NULL;
 	gcpApp = NULL;
 	Viewer = NULL;
-	App = NULL;
 	Loaded = false;
 }
 
@@ -109,26 +106,17 @@ ChemComp::~ChemComp ()
 {
 	gtk_widget_unrealize (Plug);
 	gtk_widget_destroy (Plug);
-	g_object_unref (Parent);
 }
 
 void ChemComp::SetWindow (XID xid)
 {
-	int width, height;
 	if (Viewer)
 		return;
-	if (Xid == xid) {
-		//just resize and redraw
-		gdk_window_get_geometry (Parent, NULL, NULL, &width, &height, NULL);
-		gtk_window_resize (GTK_WINDOW (Plug), width, height);
-	} else {
+	if (Xid != xid) {
 		if (Plug) // does this happen ?
 			return;
 		Xid = xid;
 		Plug = gtk_plug_new (xid);
-		Parent = gdk_window_foreign_new (xid);
-		gdk_window_get_geometry (Parent, NULL, NULL, &width, &height, NULL);
-		gtk_window_set_default_size (GTK_WINDOW (Plug), width, height);
 		gtk_widget_realize (Plug);
 		GdkWindow *window = gtk_widget_get_window (Plug);
 		XReparentWindow (GDK_WINDOW_XDISPLAY (window),
@@ -136,7 +124,7 @@ void ChemComp::SetWindow (XID xid)
 		XMapWindow (GDK_WINDOW_XDISPLAY (window),
 			GDK_WINDOW_XID (window));
 		if (MimeType == "application/x-gcrystal" || MimeType == "chemical/x-cif")
-			Viewer = gcu_crystal_viewer_new (NULL);
+			Viewer = gcr_crystal_viewer_new (NULL);
 		else if (MimeType == "application/x-gchempaint" || MimeType == "chemical/x-cdx" || MimeType == "chemical/x-cdxml") {
 			if (!gcpApp)
 				gcpApp = new MozPaintApp ();
@@ -168,7 +156,7 @@ void ChemComp::SetFilename (string& filename)
 		xmlDocPtr xml = xmlParseFile (filename.c_str ());
 		if (!xml || !xml->children || strcmp ((char*) xml->children->name, "crystal"))
 			return;
-		gcu_crystal_viewer_set_data (GCU_CRYSTAL_VIEWER (Viewer), xml->children);
+		gcr_crystal_viewer_set_data (GCR_CRYSTAL_VIEWER (Viewer), xml->children);
 		xmlFree (xml);
 	} else if (MimeType == "chemical/x-cif") {
 		if (!loaded_radii) {
@@ -180,7 +168,7 @@ void ChemComp::SetFilename (string& filename)
 			filename = uri;
 			g_free (uri);
 		}
-		gcu_crystal_viewer_set_uri_with_mime_type (GCU_CRYSTAL_VIEWER (Viewer), filename.c_str (), "chemical/x-cif");
+		gcr_crystal_viewer_set_uri_with_mime_type (GCR_CRYSTAL_VIEWER (Viewer), filename.c_str (), "chemical/x-cif");
 	} else 	if (MimeType == "application/x-gchempaint") {
 		xmlDocPtr xml = xmlParseFile (filename.c_str ());
 		if (!xml || !xml->children || strcmp ((char*) xml->children->name, "chemistry"))
@@ -340,7 +328,7 @@ int main (int argc, char *argv[])
 	gtk_init (&argc, &argv);
 	libgoffice_init ();
 	go_plugins_init (NULL, NULL, NULL, NULL, TRUE, GO_TYPE_PLUGIN_LOADER_MODULE);
-			Loader::Init ();
+	Loader::Init (Application::GetDefaultApplication ());
 	in_channel = g_io_channel_unix_new (fileno (stdin));
 	g_io_add_watch (in_channel, G_IO_IN, io_func, &error);
 	gtk_main ();
