@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint cycles plugin
- * cycletool.cc 
+ * cycletool.cc
  *
- * Copyright (C) 2001-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -37,7 +37,7 @@
 #include <gccv/canvas.h>
 #include <gccv/group.h>
 #include <gccv/line.h>
-#include <gcu/ui-builder.h>
+#include <gcugtk/ui-builder.h>
 #include <glib/gi18n-lib.h>
 #include <cmath>
 #include <list>
@@ -229,7 +229,7 @@ bool gcpCycleTool::OnClicked ()
 					while ((pBond = (gcp::Bond*) pAtom->GetNextBond (j))) {
 						k = 0;
 						a0 = pBond->GetAngle2DRad (pAtom);
-						while ((a0 > orientations[k]) && (k < orientations.size ())) 
+						while ((a0 > orientations[k]) && (k < orientations.size ()))
 							k++;
 						orientations.insert (orientations.begin () + k, a0);
 					}
@@ -269,7 +269,7 @@ bool gcpCycleTool::OnClicked ()
 		m_Points[i].x = x1 += m_dLength * cos (m_dAngle - m_dDev * (i - 1));
 		m_Points[i].y = y1 -= m_dLength * sin (m_dAngle - m_dDev * (i - 1));
 	}
-	
+
 	m_bAllowed = CheckIfAllowed ();
 	Draw ();
 	return true;
@@ -498,6 +498,7 @@ void gcpCycleTool::OnRelease ()
 	gcp::Molecule *pMol = NULL;
 	std::string MolId;
 	int i;
+	// first save groups if any will be modified
 	for (i = 0; i < m_size; i++) {
 		m_x = m_Points[i].x;
 		m_y = m_Points[i].y;
@@ -531,6 +532,9 @@ void gcpCycleTool::OnRelease ()
 				}
 			}
 		}
+	}
+	// now add missing atoms and bonds
+	for (i = 0; i < m_size; i++) {
 		if (!pAtom[i]) {
 			pAtom[i] = new gcp::Atom (m_pApp->GetCurZ (), m_Points[i].x / m_dZoomFactor, m_Points[i].y / m_dZoomFactor, 0);
 			pDoc->AddAtom (pAtom[i]);
@@ -699,7 +703,7 @@ void gcpCycleTool::SetLength (double length)
 
 GtkWidget *gcpCycleTool::GetPropertyPage ()
 {
-	gcu::UIBuilder *builder = new gcu::UIBuilder (UIDIR"/cycle.ui", GETTEXT_PACKAGE);
+	gcugtk::UIBuilder *builder = new gcugtk::UIBuilder (UIDIR"/cycle.ui", GETTEXT_PACKAGE);
 	m_LengthBtn = GTK_SPIN_BUTTON (builder->GetWidget ("bond-length"));
 	g_signal_connect (m_LengthBtn, "value-changed", G_CALLBACK (on_length_changed), this);
 	m_MergeBtn = GTK_TOGGLE_BUTTON (builder->GetWidget ("merge"));
@@ -757,7 +761,7 @@ static void on_size_changed (GtkSpinButton *button, gcpNCycleTool *tool)
 
 GtkWidget *gcpNCycleTool::GetPropertyPage ()
 {
-	gcu::UIBuilder *builder = new gcu::UIBuilder (UIDIR"/cyclen.ui", GETTEXT_PACKAGE);
+	gcugtk::UIBuilder *builder = new gcugtk::UIBuilder (UIDIR"/cyclen.ui", GETTEXT_PACKAGE);
 	m_LengthBtn = GTK_SPIN_BUTTON (builder->GetWidget ("bond-length"));
 	g_signal_connect (m_LengthBtn, "value-changed", G_CALLBACK (on_length_changed), this);
 	m_MergeBtn = GTK_TOGGLE_BUTTON (builder->GetWidget ("merge"));
