@@ -4,10 +4,10 @@
  * GChemPaint residues plugin
  * residues-dlg.cc
  *
- * Copyright (C) 2007-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2007-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -109,7 +109,8 @@ static int insert_symbol (GtkComboBox *box, char const *str)
 	GtkTreeIter iter;
 	int i = 1;
 	if (!gtk_tree_model_get_iter_from_string (model, &iter, "1")) {
-		gtk_combo_box_append_text (box, str);
+		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+		gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, str, -1);
 		return i;
 	}
 	char* text;
@@ -118,12 +119,14 @@ static int insert_symbol (GtkComboBox *box, char const *str)
 		if (gtk_tree_model_iter_next (model, &iter))
 			gtk_tree_model_get (model, &iter, 0, &text, -1);
 		else {
-			gtk_combo_box_append_text (box, str);
+			gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+			gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, str, -1);
 			return i + 1;
 		}
 		i++;
 	}
-	gtk_combo_box_insert_text (box, i, str);
+		gtk_list_store_insert (GTK_LIST_STORE (model), &iter, i);
+		gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, str, -1);
 	return i;
 }
 
@@ -131,7 +134,6 @@ static void delete_symbol (GtkComboBox *box, char const *str)
 {
 	GtkTreeModel *model = gtk_combo_box_get_model (box);
 	GtkTreeIter iter;
-	int i = 1;
 	if (!gtk_tree_model_get_iter_from_string (model, &iter, "1"))
 		return;
 	char* text;
@@ -141,13 +143,12 @@ static void delete_symbol (GtkComboBox *box, char const *str)
 			gtk_tree_model_get (model, &iter, 0, &text, -1);
 		else
 			return;
-		i++;
 	}
-	gtk_combo_box_remove_text (box, i);
+	gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
 }
 
 gcpResiduesDlg::gcpResiduesDlg (gcp::Application *App):
-	Dialog (App, UIDIR"/residues.ui", "residues", GETTEXT_PACKAGE, App),
+	gcugtk::Dialog (App, UIDIR"/residues.ui", "residues", GETTEXT_PACKAGE, App),
 	gcp::Target (App)
 {
 	m_Document = new gcp::Document (App, true, NULL);
@@ -158,8 +159,9 @@ gcpResiduesDlg::gcpResiduesDlg (gcp::Application *App):
 	gtk_scrolled_window_set_shadow_type (scroll, GTK_SHADOW_IN);
 	gtk_scrolled_window_add_with_viewport (scroll, w);
 	gtk_widget_set_size_request (GTK_WIDGET (scroll), 408, 308);
+	g_object_set (G_OBJECT (scroll), "expand", true, NULL);
 	gtk_widget_show (GTK_WIDGET (scroll));
-	gtk_box_pack_start (GTK_BOX (GetWidget ("formula-box")), GTK_WIDGET (scroll), true, true, 0);
+	gtk_grid_attach(GTK_GRID (GetWidget ("formula-grid")), GTK_WIDGET (scroll), 0, 0, 1, 1);
 	gtk_widget_show_all (GTK_WIDGET (dialog));
 	App->SetActiveDocument (m_Document);
 	gcp::Theme *theme = m_Document->GetTheme ();
@@ -179,8 +181,11 @@ gcpResiduesDlg::gcpResiduesDlg (gcp::Application *App):
 	m_CurBox = GTK_COMBO_BOX (GetWidget ("cur-box"));
 	ResidueIterator i;
 	string const *s = Residue::GetFirstResidueSymbol (i);
+	GtkListStore *list = GTK_LIST_STORE (gtk_combo_box_get_model (m_CurBox));
+	GtkTreeIter iter;
 	while (s) {
-		gtk_combo_box_append_text (m_CurBox, s->c_str ());
+		gtk_list_store_append (list, &iter);
+		gtk_list_store_set (list, &iter, 0, s->c_str (), -1);
 		s = Residue::GetNextResidueSymbol (i);
 	}
 	gtk_combo_box_set_active (m_CurBox, 0);
@@ -217,7 +222,7 @@ void gcpResiduesDlg::Add ()
 		GtkDialog* box = GTK_DIALOG (gtk_message_dialog_new (GTK_WINDOW(dialog), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, _("Please, provide only one molecule.")));
 		gtk_window_set_icon_name (GTK_WINDOW (box), m_App->GetName ().c_str ());
 		if (gtk_dialog_run (box) != GTK_RESPONSE_NONE)
-			gtk_widget_destroy (GTK_WIDGET (box));	
+			gtk_widget_destroy (GTK_WIDGET (box));
 		return;
 	}
 	if (!user_residues) {
@@ -233,12 +238,12 @@ void gcpResiduesDlg::Add ()
 		GtkDialog* box = GTK_DIALOG (gtk_message_dialog_new (GTK_WINDOW(dialog), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, _("Please, provide a name for the residue")));
 		gtk_window_set_icon_name (GTK_WINDOW (box), m_App->GetName ().c_str ());
 		if (gtk_dialog_run (box) != GTK_RESPONSE_NONE)
-			gtk_widget_destroy (GTK_WIDGET (box));	
+			gtk_widget_destroy (GTK_WIDGET (box));
 		return;
 	}
 	gcp::Residue const *r = static_cast<gcp::Residue const *> (gcp::Residue::GetResiduebyName (name));
 	if (r && r != m_Residue) {
-		
+
 	}
 	char const *symbols = gtk_entry_get_text (m_SymbolEntry);
 	std::istringstream s(symbols);
@@ -251,13 +256,13 @@ void gcpResiduesDlg::Add ()
 		GtkDialog* box = GTK_DIALOG (gtk_message_dialog_new (GTK_WINDOW(dialog), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, _("Symbols with more than eight characters are not allowed.")));
 		gtk_window_set_icon_name (GTK_WINDOW (box), m_App->GetName ().c_str ());
 		if (gtk_dialog_run (box) != GTK_RESPONSE_NONE)
-			gtk_widget_destroy (GTK_WIDGET (box));	
+			gtk_widget_destroy (GTK_WIDGET (box));
 		return;
 		} else if (!strcmp (buf, _("New"))) {
 			GtkDialog* box = GTK_DIALOG (gtk_message_dialog_new (GTK_WINDOW(dialog), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, _("\"New\" is not a valid symbol")));
 			gtk_window_set_icon_name (GTK_WINDOW (box), m_App->GetName ().c_str ());
 			if (gtk_dialog_run (box) != GTK_RESPONSE_NONE)
-				gtk_widget_destroy (GTK_WIDGET (box));	
+				gtk_widget_destroy (GTK_WIDGET (box));
 			return;
 		} else
 			sl.push_back (buf);
@@ -266,7 +271,7 @@ void gcpResiduesDlg::Add ()
 		GtkDialog* box = GTK_DIALOG (gtk_message_dialog_new (GTK_WINDOW(dialog), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, _("Please provide at least one symbol")));
 		gtk_window_set_icon_name (GTK_WINDOW (box), m_App->GetName ().c_str ());
 		if (gtk_dialog_run (box) != GTK_RESPONSE_NONE)
-			gtk_widget_destroy (GTK_WIDGET (box));	
+			gtk_widget_destroy (GTK_WIDGET (box));
 		return;
 	}
 	std::list<string>::reverse_iterator i, iend = sl.rend ();
@@ -288,7 +293,7 @@ void gcpResiduesDlg::Add ()
 		GtkDialog* box = GTK_DIALOG (gtk_message_dialog_new (GTK_WINDOW(dialog), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, _("Empty formula, this should never happen.\nPlease file a bug report")));
 		gtk_window_set_icon_name (GTK_WINDOW (box), m_App->GetName ().c_str ());
 		if (gtk_dialog_run (box) != GTK_RESPONSE_NONE)
-			gtk_widget_destroy (GTK_WIDGET (box));	
+			gtk_widget_destroy (GTK_WIDGET (box));
 		return;
 	}
 	// If we are there, everything is OK.
@@ -322,7 +327,7 @@ void gcpResiduesDlg::Add ()
 	xmlKeepBlanksDefault (0);
 	xmlSaveFormatFile ((char*) user_residues->URL, user_residues, true);
 	xmlFreeDoc (xml);
-	m_Residue->Load (node, false);
+	m_Residue->Load (node, false, m_App);
 	gtk_combo_box_set_active (m_CurBox, n);
 }
 
@@ -356,10 +361,10 @@ bool gcpResiduesDlg::OnKeyPress (GdkEventKey *event)
 // Next lines are commented out because they just do not work properly: FIXME if possible
 		if (event->state & GDK_CONTROL_MASK) {
 			switch (event->keyval) {
-			case GDK_Z:
+			case GDK_KEY_Z:
 				m_Document->OnRedo ();
 				break;
-			case GDK_z:
+			case GDK_KEY_z:
 				m_Document->OnUndo ();
 				break;
 			}
@@ -367,9 +372,9 @@ bool gcpResiduesDlg::OnKeyPress (GdkEventKey *event)
 		}
 		// Only when editing the residue
 		switch (event->keyval) {
-		case GDK_Delete:
-		case GDK_Clear:
-		case GDK_BackSpace: {
+		case GDK_KEY_Delete:
+		case GDK_KEY_Clear:
+		case GDK_KEY_BackSpace: {
 			// the molecule must not be deleted
 			Object *mol = m_Atom->GetMolecule ();
 			gcp::WidgetData *data = reinterpret_cast<gcp::WidgetData*> (g_object_get_data (reinterpret_cast<GObject*> (m_Document->GetWidget ()), "data"));
@@ -398,7 +403,13 @@ bool gcpResiduesDlg::OnKeyRelease (GdkEventKey *event)
 
 void gcpResiduesDlg::OnCurChanged ()
 {
-	char *symbol = gtk_combo_box_get_active_text (m_CurBox);
+	char *symbol;
+	GtkTreeIter iter;
+	GtkTreePath *path = gtk_tree_path_new_from_indices (gtk_combo_box_get_active (m_CurBox), -1);
+	GtkTreeModel *model = gtk_combo_box_get_model (m_CurBox);
+	gtk_tree_model_get_iter (model, &iter, path);
+	gtk_tree_path_free (path);
+	gtk_tree_model_get (model, &iter, 0, &symbol, -1);
 	if (!strcmp (symbol, _("New"))) {
 		m_Residue = NULL;
 		gtk_entry_set_text (m_NameEntry, "");
@@ -409,6 +420,7 @@ void gcpResiduesDlg::OnCurChanged ()
 		gtk_widget_set_sensitive (m_DeleteBtn, false);
 		gtk_widget_set_sensitive (m_GenericBtn, true);
 		m_Document->SetEditable (true);
+		g_free (symbol);
 		return;
 	}
 	m_Residue = const_cast <gcp::Residue *> (static_cast<gcp::Residue const*> (Residue::GetResidue (symbol)));
@@ -435,11 +447,11 @@ void gcpResiduesDlg::OnCurChanged ()
 		sy = (*i).first;
 	for (i++; i != end; i++)
 		sy += string(";") + (*i).first;
-	gtk_entry_set_text (m_SymbolEntry, sy.c_str ());	
+	gtk_entry_set_text (m_SymbolEntry, sy.c_str ());
 	m_Document->Clear ();
 	m_Document->LoadObjects (m_Residue->GetMolNode ());
 	double r =  m_Document->GetTheme ()->GetBondLength () / m_Document->GetMedianBondLength ();
-	if (fabs (r - 1.) > .0001) { 
+	if (fabs (r - 1.) > .0001) {
 		Matrix2D m (r, 0., 0., r);
 		m_Document->Transform2D (m, 0., 0.);
 		m_Document->GetView ()->Update (m_Document);
@@ -452,6 +464,7 @@ void gcpResiduesDlg::OnCurChanged ()
 	static_cast <gcp::Atom *>((*j).first)->Lock ();
 	static_cast <gcp::Bond *>((*j).second)->Lock ();
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (m_GenericBtn), m_Residue->GetGeneric ());
+	g_free (symbol);
 }
 
 void gcpResiduesDlg::OnSymbolActivate ()
@@ -475,8 +488,12 @@ void gcpResiduesDlg::OnNewResidue (gcp::Residue *res)
 	if (res) {
 		map<string, bool> const &symbols = res->GetSymbols ();
 		map<string, bool>::const_iterator i = symbols.begin (), end = symbols.end ();
-		for (i = symbols.begin (); i != end; i++)
-			gtk_combo_box_append_text (m_CurBox, (*i).first.c_str ());
+		GtkListStore *list = GTK_LIST_STORE (gtk_combo_box_get_model (m_CurBox));
+		GtkTreeIter iter;
+		for (i = symbols.begin (); i != end; i++) {
+			gtk_list_store_append (list, &iter);
+			gtk_list_store_set (list, &iter, 0, (*i).first.c_str (), -1);
+		}
 	} else if (m_Residue && !m_Residue->GetReadOnly ())
 		gtk_widget_set_sensitive (m_DeleteBtn, m_Residue->GetRefs () == 0);
 }
