@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint text plugin
- * texttool.cc 
+ * texttool.cc
  *
- * Copyright (C) 2002-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -37,7 +37,7 @@
 #include <gcp/window.h>
 #include <gccv/text.h>
 #include <gccv/text-tag.h>
-#include <gcu/ui-builder.h>
+#include <gcugtk/ui-builder.h>
 #include <gdk/gdkkeysyms.h>
 #include <unistd.h>
 #include <cstring>
@@ -106,6 +106,7 @@ bool gcpTextTool::OnClicked ()
 	if (!m_pObject) {
 		gcp::Text *text = new gcp::Text(m_x0 / pTheme->GetZoomFactor (), m_y0 / pTheme->GetZoomFactor ());
 		m_pView->GetDoc ()->AddObject (text);
+		m_pView->GetDoc ()->AbortOperation ();
 		m_pObject = text;
 		create = true;
 	}
@@ -145,63 +146,63 @@ bool gcpTextTool::OnKeyPress (GdkEventKey* event)
 	if (m_Active) {
 		if (event->state & GDK_CONTROL_MASK) {
 			switch (event->keyval) {
-			case GDK_Right:
-			case GDK_Left:
-			case GDK_Up:
-			case GDK_Down:
-			case GDK_End:
-			case GDK_Home:
-			case GDK_Delete:
-			case GDK_KP_Delete:
-			case GDK_BackSpace:
+			case GDK_KEY_Right:
+			case GDK_KEY_Left:
+			case GDK_KEY_Up:
+			case GDK_KEY_Down:
+			case GDK_KEY_End:
+			case GDK_KEY_Home:
+			case GDK_KEY_Delete:
+			case GDK_KEY_KP_Delete:
+			case GDK_KEY_BackSpace:
 				break;
-			case GDK_a:
+			case GDK_KEY_a:
 				m_pView->OnSelectAll ();
 				return true;
-			case GDK_z:
+			case GDK_KEY_z:
 				m_pView->GetDoc()->OnUndo ();
 				return true;
-			case GDK_Z:
+			case GDK_KEY_Z:
 				m_pView->GetDoc()->OnRedo ();
 				return true;
-			case GDK_c:
+			case GDK_KEY_c:
 				CopySelection (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD));
 				return true;
-			case GDK_v:
+			case GDK_KEY_v:
 				PasteSelection (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD));
 				return true;
-			case GDK_x:
+			case GDK_KEY_x:
 				CutSelection (gtk_clipboard_get (GDK_SELECTION_CLIPBOARD));
 				return true;
-			case GDK_i:
+			case GDK_KEY_i:
 				m_Style = (m_Style == PANGO_STYLE_NORMAL)? PANGO_STYLE_ITALIC: PANGO_STYLE_NORMAL;
 				SelectBestFontFace ();
 				BuildTagsList ();
 				return true;
-			case GDK_u:
+			case GDK_KEY_u:
 				gtk_combo_box_set_active (m_UnderlineBox, ((m_Underline == gccv::TextDecorationDefault)? 0: 1));
 				return true;
-			case GDK_b:
+			case GDK_KEY_b:
 				m_Weight = (m_Weight == PANGO_WEIGHT_NORMAL)? PANGO_WEIGHT_BOLD: PANGO_WEIGHT_NORMAL;
 				SelectBestFontFace ();
 				BuildTagsList ();
 				return true;
-			case GDK_k:
+			case GDK_KEY_k:
 				gtk_toggle_button_set_active (m_StrikethroughBtn, !m_Strikethrough);
 				return true;
-			case GDK_plus:
-			case GDK_dead_circumflex:
-			case GDK_KP_Add:
-			case GDK_asciicircum:
+			case GDK_KEY_plus:
+			case GDK_KEY_dead_circumflex:
+			case GDK_KEY_KP_Add:
+			case GDK_KEY_asciicircum:
 				m_Position = (m_Position == gccv::Superscript)? gccv::Normalscript: gccv::Superscript;
 				BuildTagsList ();
 				return true;
-			case GDK_equal:
-			case GDK_underscore:
+			case GDK_KEY_equal:
+			case GDK_KEY_underscore:
 				m_Position = (m_Position == gccv::Subscript)? gccv::Normalscript: gccv::Subscript;
 				BuildTagsList ();
 				return true;
-			case GDK_space: {
+			case GDK_KEY_space: {
 				gccv::Text *saved = m_Active;
 				m_Active = NULL;
 				UpdateTagsList ();
@@ -209,23 +210,23 @@ bool gcpTextTool::OnKeyPress (GdkEventKey* event)
 				BuildTagsList ();
 				return true;
 			}
-			case GDK_l:
+			case GDK_KEY_l:
 				if (m_Active)
 					m_Active->SetJustification (GTK_JUSTIFY_LEFT, true);
 				return true;
-			case GDK_r:
+			case GDK_KEY_r:
 				if (m_Active)
 					m_Active->SetJustification (GTK_JUSTIFY_RIGHT, true);
 				return true;
-			case GDK_j:
+			case GDK_KEY_j:
 				if (m_Active)
 					m_Active->SetJustification (GTK_JUSTIFY_FILL, true);
 				return true;
-			case GDK_m:
+			case GDK_KEY_m:
 				if (m_Active)
 					m_Active->SetJustification (GTK_JUSTIFY_CENTER, true);
 				return true;
-			case GDK_w:
+			case GDK_KEY_w:
 				if (m_Active) {
 					double w = m_Active->GetInterline ();
 					if (w == 0.)
@@ -234,8 +235,8 @@ bool gcpTextTool::OnKeyPress (GdkEventKey* event)
 					m_Active->SetInterline ((w > 0.? w: 0.), true);
 				}
 				return true;
-			case GDK_W:
-				if (m_Active) 
+			case GDK_KEY_W:
+				if (m_Active)
 					m_Active->SetInterline (m_Active->GetInterline () + 1., true);
 				return true;
 			default:
@@ -302,6 +303,8 @@ bool gcpTextTool::Unselect ()
 		if (m_Group) {
 			pOp = m_pView->GetDoc ()->GetCurrentOperation ();
 			if (pOp && dynamic_cast <gcp::ModifyOperation *> (pOp) == NULL) {
+				// looks like gcp::Document::AddObject sometimes add a new and unneeded AddOperation
+				// adding that as a security, but it looks like a bug.
 				m_pView->GetDoc ()->AbortOperation ();
 				pOp = NULL;
 			}
@@ -622,7 +625,7 @@ void gcpTextTool::OnGetData (GtkClipboard *clipboard, GtkSelectionData *selectio
 	if (info) {
 		if (gcp::ClipboardTextData) {
 			g_free (gcp::ClipboardTextData);
-		} 
+		}
 		gcp::Text *text = new gcp::Text ();
 		text->Load (pDoc->children->children);
 		gcp::ClipboardTextData = g_strdup (text->GetBuffer ().c_str ());
@@ -832,7 +835,7 @@ static const guint16 font_sizes[] = {
 
 GtkWidget *gcpTextTool::GetPropertyPage ()
 {
-	gcu::UIBuilder *builder = new gcu::UIBuilder (UIDIR"/fontsel.ui", GETTEXT_PACKAGE);
+	gcugtk::UIBuilder *builder = new gcugtk::UIBuilder (UIDIR"/fontsel.ui", GETTEXT_PACKAGE);
 	PangoFontFamily **families;
 	int i, nb;
 	gcp::Theme *pTheme = m_pApp->GetActiveDocument ()->GetTheme ();
@@ -936,7 +939,8 @@ GtkWidget *gcpTextTool::GetPropertyPage ()
 	go_color_selector_set_allow_alpha (m_ColorSelector, false);
 	m_ForeSignal = g_signal_connect (G_OBJECT (m_ColorSelector), "activate", G_CALLBACK (on_fore_color_changed), this);
 	gtk_widget_show (GTK_WIDGET (m_ColorSelector));
-	gtk_table_attach (GTK_TABLE (builder->GetWidget ("table2")), GTK_WIDGET (m_ColorSelector), 1, 2, 0, 1, (GtkAttachOptions) 0, (GtkAttachOptions) 0, 0, 0);
+	g_object_set (G_OBJECT (m_ColorSelector), "halign", GTK_ALIGN_START, NULL);
+	gtk_grid_attach (GTK_GRID (builder->GetWidget ("details")), GTK_WIDGET (m_ColorSelector), 1, 1, 1, 1);
 	GtkWidget *res = builder->GetRefdWidget ("fontsel");
 	delete builder;
 	return res;
@@ -1064,7 +1068,7 @@ void gcpTextTool::SetSizeFull (bool update_list, bool apply)
 		bool found = false;
 		GtkTreeSelection *selection = gtk_tree_view_get_selection (m_SizesTree);
 		g_signal_handler_block (selection, m_SizeSignal);
-		
+
 		gtk_tree_model_get_iter_first (GTK_TREE_MODEL (m_SizeList), &iter);
 		for (unsigned i = 0; i < G_N_ELEMENTS (font_sizes) && !found; i++) {
 			if (font_sizes[i] * PANGO_SCALE == m_Size) {
@@ -1076,7 +1080,7 @@ void gcpTextTool::SetSizeFull (bool update_list, bool apply)
 
 			gtk_tree_model_iter_next (GTK_TREE_MODEL (m_SizeList), &iter);
 		}
-		
+
 		if (!found)
 			gtk_tree_selection_unselect_all (selection);
 		g_signal_handler_unblock (selection, m_SizeSignal);
