@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemistry Utils
- * programs/3d/view.h 
+ * programs/3d/view.h
  *
- * Copyright (C) 2006 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2006-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -25,14 +25,12 @@
 #ifndef GC3D_VIEW_H
 #define GC3D_VIEW_H
 
-#include <gcu/glview.h>
-
-using namespace gcu;
+#include <gcugtk/glview.h>
 
 class gc3dDocument;
 class gc3dWindow;
 
-class gc3dView: public GLView
+class gc3dView: public gcugtk::GLView
 {
 public:
 	gc3dView (gc3dDocument *Doc);
