@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Chemistry Utils
- * programs/calc/gchemcalc.cc 
+ * programs/calc/gchemcalc.cc
  *
- * Copyright (C) 2005-2010 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -23,17 +23,17 @@
  */
 
 #include "config.h"
-#include <gcu/application.h>
+#include <gcugtk/application.h>
+#include <gcugtk/filechooser.h>
+#include <gcugtk/printable.h>
+#include <gcugtk/print-setup-dlg.h>
+#include <gcugtk/ui-builder.h>
 #include <gcu/atom.h>
 #include <gcu/bond.h>
 #include <gcu/document.h>
 #include <gcu/element.h>
-#include <gcu/filechooser.h>
 #include <gcu/formula.h>
 #include <gcu/molecule.h>
-#include <gcu/printable.h>
-#include <gcu/print-setup-dlg.h>
-#include <gcu/ui-builder.h>
 #include <gcu/residue.h>
 #include <gcu/value.h>
 #include <glib/gi18n.h>
@@ -49,7 +49,7 @@ using namespace gcu;
 
 using namespace std;
 
-class GChemCalc: public Application, public Printable
+class GChemCalc: public gcugtk::Application, public gcugtk::Printable
 {
 public:
 	GChemCalc ();
@@ -100,7 +100,7 @@ static Object* CreateDocument ()
 }
 
 GChemCalc::GChemCalc ():
-	Application ("gchemcalc"),
+	gcugtk::Application ("gchemcalc"),
 	formula ("")
 {
 	AddType ("atom", CreateAtom, AtomType);
@@ -156,13 +156,13 @@ void GChemCalc::DoPrint (G_GNUC_UNUSED GtkPrintOperation *print, GtkPrintContext
 	w = m_GraphWidth;
 	h = m_GraphHeight;
 	switch (GetScaleType ()) {
-	case GCU_PRINT_SCALE_NONE:
+	case gcugtk::GCU_PRINT_SCALE_NONE:
 		break;
-	case GCU_PRINT_SCALE_FIXED:
+	case gcugtk::GCU_PRINT_SCALE_FIXED:
 		w *= Printable::GetScale ();
 		h *= Printable::GetScale ();
 		break;
-	case GCU_PRINT_SCALE_AUTO:
+	case gcugtk::GCU_PRINT_SCALE_AUTO:
 		if (GetHorizFit ())
 			w = width;
 		if (GetVertFit ())
@@ -195,7 +195,7 @@ void GChemCalc::OnSaveAsImage ()
 	l.push_front ("application/postscript");
 	l.push_front ("application/pdf");
 	l.push_front ("image/svg+xml");
-	FileChooser (this, true, l, NULL, _("Save as image"), GetImageSizeWidget ());
+	gcugtk::FileChooser (this, true, l, NULL, _("Save as image"), GetImageSizeWidget ());
 }
 
 bool GChemCalc::FileProcess (const gchar* filename, const gchar* mime_type, bool bSave, G_GNUC_UNUSED GtkWindow *window, G_GNUC_UNUSED Document *pDoc)
@@ -230,7 +230,7 @@ bool GChemCalc::FileProcess (const gchar* filename, const gchar* mime_type, bool
 			gog_graph_set_size (gr, GetImageWidth (), GetImageHeight ());
 			gog_graph_export_image (gr, format, output, -1., -1.);
 			g_object_unref (gr);
-			
+
 		}
 		g_object_unref (file);
 	}
@@ -275,11 +275,6 @@ static void on_bug (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED gpointer data
 	App->OnBug ();
 }
 
-static void on_about_activate_url (G_GNUC_UNUSED GtkAboutDialog *about, const gchar *url, G_GNUC_UNUSED gpointer data)
-{
-	App->OnWeb (url);
-}
-
 static void on_about (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED void *data)
 {
 	const gchar * authors[] = {"Jean Bréfort", NULL};
@@ -299,8 +294,6 @@ static void on_about (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED void *data)
 		"along with this program; if not, write to the Free Software\n"
 		"Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02111-1307\n"
 		"USA";
-	
-	gtk_about_dialog_set_url_hook (on_about_activate_url, NULL, NULL);
 
 	/* Note to translators: replace the following string with the appropriate credits for you lang */
 	const gchar * translator_credits = _("translator_credits");
@@ -317,6 +310,11 @@ static void on_about (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED void *data)
 	                       NULL);
 }
 
+static void clear_values (double *values)
+{
+	delete [] values;
+}
+
 static void cb_entry_active (GtkEntry *entry, gpointer data)
 {
 	GError *error;
@@ -333,13 +331,12 @@ static void cb_entry_active (GtkEntry *entry, gpointer data)
 		DimensionalValue weight = App->formula.GetMolecularWeight (artificial);
 		char *weightstr = (artificial)?
 			g_strdup_printf ("(%.0f g.mol<sup>-1</sup>)",weight.GetAsDouble ()):
-			g_strdup (weight.GetAsString ());			
+			g_strdup (weight.GetAsString ());
 		gtk_label_set_markup (App->weight, weightstr);
 		g_free (weightstr);
 		// Composition
 		gtk_list_store_clear (App->pclist);
 		map<int,int> &raw = App->formula.GetRawFormula ();
-		map<int,int>::iterator ri, riend = raw.end ();
 		double pcent;
 		map<string, int> elts;
 		int nC = 0, nH = 0;
@@ -430,9 +427,9 @@ static void cb_entry_active (GtkEntry *entry, gpointer data)
 				x[i] = mass + n;
 				y[i] = values[n];
 			}
-			GOData *data = go_data_vector_val_new (x, max, g_free);
+			GOData *data = go_data_vector_val_new (x, max, reinterpret_cast <GDestroyNotify> (clear_values));
 			gog_series_set_dim (App->series, 0, data, &error);
-			data = go_data_vector_val_new (y, max, g_free);
+			data = go_data_vector_val_new (y, max, reinterpret_cast <GDestroyNotify> (clear_values));
 			gog_series_set_dim (App->series, 1, data, &error);
 			g_free (values);
 			// set axis bounds
@@ -487,17 +484,17 @@ static void on_get_data (G_GNUC_UNUSED GtkClipboard *clipboard, GtkSelectionData
 	case 0: {
 			GsfXMLOut *xout;
 			char *old_num_locale, *old_monetary_locale;
-		
+
 			old_num_locale = g_strdup (go_setlocale (LC_NUMERIC, NULL));
 			go_setlocale (LC_NUMERIC, "C");
 			old_monetary_locale = g_strdup (go_setlocale (LC_MONETARY, NULL));
 			go_setlocale (LC_MONETARY, "C");
 			go_locale_untranslated_booleans ();
-		
+
 			xout = gsf_xml_out_new (output);
 			gog_object_write_xml_sax (GOG_OBJECT (graph), xout, NULL);
 			g_object_unref (xout);
-		
+
 			/* go_setlocale restores bools to locale translation */
 			go_setlocale (LC_MONETARY, old_monetary_locale);
 			g_free (old_monetary_locale);
@@ -519,7 +516,7 @@ static void on_get_data (G_GNUC_UNUSED GtkClipboard *clipboard, GtkSelectionData
 		true;
 	if (res) {
 		osize = gsf_output_size (output);
-				
+
 		buffer = (guchar*) g_malloc (osize);
 		memcpy (buffer, gsf_output_memory_get_bytes (omem), osize);
 		gsf_output_close (output);
@@ -568,7 +565,7 @@ static void on_print_preview ()
 
 static void on_page_setup ()
 {
-	new PrintSetupDlg (App, App);
+	new gcugtk::PrintSetupDlg (App, App);
 }
 
 static void on_save_as_image ()
@@ -677,7 +674,7 @@ gboolean cb_print_version (G_GNUC_UNUSED const gchar *option_name, G_GNUC_UNUSED
 	return TRUE;
 }
 
-static GOptionEntry options[] = 
+static GOptionEntry options[] =
 {
   { "version", 'v', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, (void*) cb_print_version, "prints GChemCalc version", NULL },
    { NULL, 0, 0, G_OPTION_ARG_NONE, NULL, NULL, NULL }
@@ -711,18 +708,18 @@ int main (int argc, char *argv[])
 	}
 
 	App = new GChemCalc ();
-	
+
 	/* Initialize plugins manager */
 	go_plugins_init (NULL, NULL, NULL, NULL, TRUE, GO_TYPE_PLUGIN_LOADER_MODULE);
 
-	UIBuilder *builder = new UIBuilder (UIDIR"/gchemcalc.ui", GETTEXT_PACKAGE);
+	gcugtk::UIBuilder *builder = new gcugtk::UIBuilder (UIDIR"/gchemcalc.ui", GETTEXT_PACKAGE);
 	App->window = GTK_WINDOW (builder->GetRefdWidget ("gchemcalc"));
 	gtk_window_set_icon_name (App->window, App->GetIconName ().c_str ());
-	g_signal_connect (GTK_OBJECT (App->window), "destroy",
+	g_signal_connect (G_OBJECT (App->window), "destroy",
 		 G_CALLBACK (gtk_main_quit),
 		 NULL);
-	
-	GtkWidget *vbox = builder->GetWidget ("vbox1");
+
+	GtkWidget *grid = builder->GetWidget ("calc-grid");
 	GtkUIManager *ui_manager = gtk_ui_manager_new ();
 	App->SetUIManager (ui_manager);
 	GtkActionGroup *action_group = gtk_action_group_new ("MenuActions");
@@ -738,8 +735,7 @@ int main (int argc, char *argv[])
 		exit (EXIT_FAILURE);
 	}
 	GtkWidget *bar = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
-	gtk_box_pack_start (GTK_BOX (vbox), bar, FALSE, FALSE, 0);
-	gtk_box_reorder_child (GTK_BOX (vbox), bar, 0);
+	gtk_grid_attach (GTK_GRID (grid), bar, 0, 0, 2, 1);
 	App->markup = GTK_LABEL (builder->GetWidget ("markup"));
 	App->raw = GTK_LABEL (builder->GetWidget ("raw"));
 	App->weight = GTK_LABEL (builder->GetWidget ("weight"));
@@ -767,7 +763,7 @@ int main (int argc, char *argv[])
 	gtk_tree_view_column_set_sizing (GTK_TREE_VIEW_COLUMN (column), GTK_TREE_VIEW_COLUMN_FIXED);
 	gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN (column), 150);
 	gtk_tree_view_append_column (tree, column);
-	
+
 	// Add isotopic pattern chart
 	App->mono = GTK_LABEL (builder->GetWidget ("mono"));
 	App->monomass = GTK_LABEL (builder->GetWidget ("monomass"));
@@ -775,7 +771,8 @@ int main (int argc, char *argv[])
 	App->graph_widget = go_graph_widget_new (NULL);
 	g_signal_connect_swapped (App->graph_widget, "size-allocate", G_CALLBACK (GChemCalc::OnSize), App);
 	gtk_widget_show (App->graph_widget);
-	gtk_box_pack_end (GTK_BOX (App->pattern_page), App->graph_widget, TRUE, TRUE, 0);
+	gtk_grid_attach (GTK_GRID (App->pattern_page), App->graph_widget, 0, 1, 2, 1);
+	g_object_set (G_OBJECT (App->graph_widget), "hexpand", true, "vexpand", true, NULL);
 	App->graph = go_graph_widget_get_graph (GO_GRAPH_WIDGET (App->graph_widget));
 	App->chart = go_graph_widget_get_chart (GO_GRAPH_WIDGET (App->graph_widget));
 	App->plot = (GogPlot *) gog_plot_new_by_name ("GogXYPlot");
@@ -795,7 +792,7 @@ int main (int argc, char *argv[])
 
 	gtk_widget_hide (App->pattern_page);
 	GtkWidget *w = builder->GetWidget ("entry");
-	g_signal_connect (GTK_OBJECT (w), "activate",
+	g_signal_connect (G_OBJECT (w), "activate",
 		 G_CALLBACK (cb_entry_active),
 		 App->window);
 	gcu_element_load_databases ("isotopes", NULL);
@@ -805,7 +802,7 @@ int main (int argc, char *argv[])
 		cb_entry_active (GTK_ENTRY (w), App->window);
 	}
 
-	w = builder->GetWidget ("notebook1");
+	w = builder->GetWidget ("calc-book");
 	g_signal_connect (w, "switch-page", G_CALLBACK (on_page), NULL);
 	on_page (NULL, NULL, 0); // force menus deactivation
 
