@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Crystal
- * document.cc 
+ * document.cc
  *
- * Copyright (C) 2000-2009 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2000-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -31,14 +31,10 @@
 #include "document.h"
 #include "view.h"
 #include "window.h"
-#include "celldlg.h"
-#include "atomsdlg.h"
-#include "linesdlg.h"
-#include "sizedlg.h"
-#include "cleavagesdlg.h"
 #include "globals.h"
+#include <gcugtk/filechooser.h>
 #include <gcu/objprops.h>
-#include <gcu/filechooser.h>
+#include <gcu/xml-utils.h>
 #include <libxml/parserInternals.h>
 #include <libxml/xmlmemory.h>
 #include <clocale>
@@ -62,7 +58,7 @@
 
 using namespace std;
 
-gcDocument::gcDocument (gcApplication *pApp) :CrystalDoc (pApp)
+gcDocument::gcDocument (gcApplication *pApp): gcr::Document (pApp)
 {
 	Init ();
 	m_filename = NULL;
@@ -71,120 +67,36 @@ gcDocument::gcDocument (gcApplication *pApp) :CrystalDoc (pApp)
 	m_Author = m_Mail = m_Label = m_Comment = NULL;
 	g_date_set_time_t (&m_CreationDate, time (NULL));
 	g_date_clear (&m_RevisionDate, 1);
+	m_DefaultLabel = _("Gnome Crystal");
 }
 
-gcDocument::~gcDocument()
-{
-	g_free(m_filename);
-	Reinit();
-	Dialog *dialog;
-	while (!m_Dialogs.empty())
-	{
-		dialog = m_Dialogs.front();
-		m_Dialogs.pop_front();
-		dialog->Destroy();
-	}
-}
-
-void gcDocument::Define (unsigned nPage)
+gcDocument::~gcDocument ()
 {
+	g_free (m_filename);
+	Reinit ();
 	gcu::Dialog *dialog;
-	switch(nPage) {
-	case 0:
-		dialog = GetDialog ("cell");
-		if (dialog)
-			dialog->Present ();
-		else
-			new gcCellDlg (dynamic_cast <gcApplication *> (m_App), this);
-		break;
-	case 1:
-		dialog = GetDialog ("atoms");
-		if (dialog)
-			dialog->Present ();
-		else
-			new gcAtomsDlg (dynamic_cast <gcApplication *> (m_App), this);
-		break;
-	case 2:
-		dialog = GetDialog ("lines");
-		if (dialog)
-			dialog->Present ();
-		else
-			new gcLinesDlg (dynamic_cast <gcApplication *> (m_App), this);
-		break;
-	case 3:
-		dialog = GetDialog ("size");
-		if (dialog)
-			dialog->Present ();
-		else
-			new gcSizeDlg (dynamic_cast <gcApplication *> (m_App), this);
-		break;
-	case 4:
-		dialog = GetDialog ("cleavages");
-		if (dialog)
-			dialog->Present ();
-		else
-			new gcCleavagesDlg (dynamic_cast <gcApplication *> (m_App), this);
-		break;
+	while (!m_Dialogs.empty ()) {
+		dialog = m_Dialogs.front ();
+		m_Dialogs.pop_front ();
+		dialog->Destroy ();
 	}
 }
 
 void gcDocument::Update()
 {
-	CrystalDoc::Update();
+	gcr::Document::Update();
 	UpdateAllViews();
 }
 
 void gcDocument::UpdateAllViews()
 {
-	list<CrystalView*>::iterator i;
+	list<gcr::View*>::iterator i;
 	for (i = m_Views.begin(); i != m_Views.end(); i++) {
 		(*i)->Update();
 		static_cast <gcView *> (*i)->GetWindow ()->ClearStatus ();
 	}
 }
 
-void gcDocument::GetSize(gdouble* xmin, gdouble* xmax, gdouble* ymin, gdouble* ymax, gdouble* zmin, gdouble* zmax)
-{
-	*xmin = m_xmin;
-	*xmax = m_xmax;
-	*ymin = m_ymin;
-	*ymax = m_ymax;
-	*zmin = m_zmin;
-	*zmax = m_zmax;
-}
-
-void gcDocument::SetSize(gdouble xmin, gdouble xmax, gdouble ymin, gdouble ymax, gdouble zmin, gdouble zmax)
-{
-	m_xmin = xmin;
-	m_xmax = xmax;
-	m_ymin = ymin;
-	m_ymax = ymax;
-	m_zmin = zmin;
-	m_zmax = zmax;
-}
-
-void gcDocument::GetCell(gcLattices *lattice, gdouble *a, gdouble *b, gdouble *c, gdouble *alpha, gdouble *beta, gdouble *gamma)
-{
-	*lattice = m_lattice;
-	*a = m_a;
-	*b = m_b;
-	*c = m_c;
-	*alpha = m_alpha;
-	*beta = m_beta;
-	*gamma = m_gamma;
-}
-
-void gcDocument::SetCell(gcLattices lattice, gdouble a, gdouble b, gdouble c, gdouble alpha, gdouble beta, gdouble gamma)
-{
-	m_lattice = lattice;
-	m_a = a;
-	m_b = b;
-	m_c = c;
-	m_alpha = alpha;
-	m_beta = beta;
-	m_gamma = gamma;
-}
-
 void gcDocument::SetFileName (const string &filename)
 {
 	GFile *file = g_file_new_for_uri (filename.c_str ());
@@ -217,26 +129,29 @@ void gcDocument::SetFileName (const string &filename)
 	int j = filename.length () - 1;
 	while ((i < j) && (m_filename[j] != '.'))
 		j--;
+	char *buf = (strcmp (m_filename + j, ".gcrystal"))? g_strdup (m_filename + i): g_strndup (m_filename + i, j - i);
+	char *unescaped = g_uri_unescape_string (buf, NULL);
+	g_free (buf);
+	m_DefaultLabel = unescaped;
 	if (m_Title.length () == 0) {
 		g_free (m_Label);
-		char *buf = (strcmp (m_filename + j, ".gcrystal"))? g_strdup (m_filename + i): g_strndup (m_filename + i, j - i);
-		m_Label = g_uri_unescape_string (buf, NULL);
-		g_free (buf);
-	}
+		m_Label = unescaped;
+	} else
+		g_free (unescaped);
 }
 
 void gcDocument::SetTitle(const gchar* title)
 {
-	m_Title = title;
-	g_free(m_Label);
-	m_Label = g_strdup(title);	
+	m_Title = title? title: "";
+	g_free (m_Label);
+	m_Label = title? g_strdup (title): NULL;
 }
 
 void gcDocument::SetTitle (std::string& title)
 {
 	m_Title = title;
 	g_free (m_Label);
-	m_Label = g_strdup (title.c_str ());	
+	m_Label = title.length ()? g_strdup (title.c_str ()): NULL;
 }
 
 static int cb_xml_to_vfs (GOutputStream *output, const char* buf, int nb)
@@ -262,11 +177,8 @@ void gcDocument::Save() const
 		if (!g_date_valid (&m_CreationDate))
 			g_date_set_time_t (&const_cast <gcDocument *> (this)->m_CreationDate, time (NULL));
 		g_date_set_time_t (&const_cast <gcDocument *> (this)->m_RevisionDate, time (NULL));
-		gchar tmp[64];
-		g_date_strftime (tmp, sizeof (tmp), "%m/%d/%Y", &m_CreationDate);
-		xmlNewProp (xml->children, (xmlChar*) "creation", (xmlChar*) tmp);
-		g_date_strftime (tmp, sizeof (tmp), "%m/%d/%Y", &m_RevisionDate);
-		xmlNewProp (xml->children, (xmlChar*) "revision", (xmlChar*) tmp);
+		gcu::WriteDate (xml->children, "creation", &m_CreationDate);
+		gcu::WriteDate (xml->children, "revision", &m_RevisionDate);
 		xmlNodePtr node;
 
 		if (m_Title.length () > 0) {
@@ -297,7 +209,7 @@ void gcDocument::Save() const
 		}
 		xmlIndentTreeOutput = true;
 		xmlKeepBlanksDefault (0);
-	
+
 		xmlOutputBufferPtr buf = xmlAllocOutputBuffer (NULL);
 		GFile *file = g_file_new_for_uri (m_filename);
 		GError *error = NULL;
@@ -420,13 +332,11 @@ bool gcDocument::Load (const string &filename)
 
 void gcDocument::ParseXMLTree(xmlNode* xml)
 {
-	char *old_num_locale, *txt;
+	char *txt;
 	xmlNodePtr node;
 	bool bViewLoaded = false;
 
 	Reinit();
-	old_num_locale = g_strdup(setlocale(LC_NUMERIC, NULL));
-	setlocale(LC_NUMERIC, "C");
 	//look for generator node
 	unsigned version = 0xffffff , major, minor, micro;
 	node = xml->children;
@@ -442,22 +352,9 @@ void gcDocument::ParseXMLTree(xmlNode* xml)
 		g_free (m_Comment);
 		m_Comment = NULL;
 	}
-	g_date_clear (&m_CreationDate, 1);
-	g_date_clear (&m_RevisionDate, 1);
-	txt = (char*) xmlGetProp (xml, (xmlChar*) "creation");
-	if (txt) {
-		g_date_set_parse (&m_CreationDate, txt);
-		if (!g_date_valid (&m_CreationDate))
-			g_date_clear (&m_CreationDate, 1);
-		xmlFree (txt);
-	}
-	txt = (char*) xmlGetProp (xml, (xmlChar*) "revision");
-	if (txt) {
-		g_date_set_parse (&m_RevisionDate, txt);
-		if (!g_date_valid(&m_RevisionDate))
-			g_date_clear(&m_RevisionDate, 1);
-		xmlFree (txt);
-	}
+
+	gcu::ReadDate (xml, "creation", &m_CreationDate);
+	gcu::ReadDate (xml, "revision", &m_RevisionDate);
 
 	node = GetNodeByName (xml, "title");
 	if (node) {
@@ -505,69 +402,59 @@ void gcDocument::ParseXMLTree(xmlNode* xml)
 	}
 	if (version >= 0x500)
 	{
-		CrystalDoc::ParseXMLTree(xml);
+		gcr::Document::ParseXMLTree(xml);
 	}
 	else
 	{
 		node = xml->children;
-		while(node)
-		{
-			if (!strcmp((gchar*)node->name, "lattice"))
-			{
+		while(node) {
+			if (!strcmp((gchar*)node->name, "lattice")) {
 				txt = (char*)xmlNodeGetContent(node);
-				if (txt)
-				{
+				if (txt) {
 					int i = 0;
-					while (strcmp(txt, LatticeName[i]) && (i < 14)) i++;
-					if (i < 14) m_lattice = (gcLattices)i;
-					xmlFree(txt);
+					while (strcmp (txt, gcr::LatticeName[i]) && (i < 14))
+						i++;
+					if (i < 14)
+						m_lattice = (gcr::Lattice) i;
+					xmlFree (txt);
 				}
-			}
-			else if (!strcmp((gchar*)node->name, "cell"))
-			{
-				txt = (char*)xmlNodeGetContent(node);
-				if (txt)
-				{
-					sscanf(txt, "%lg %lg %lg %lg %lg %lg", &m_a, &m_b, &m_c, &m_alpha, &m_beta, &m_gamma);
-					xmlFree(txt);
+			} else if (!strcmp ((gchar*) node->name, "cell")) {
+				txt = (char*) xmlNodeGetContent (node);
+				if (txt) {
+					sscanf (txt, "%lg %lg %lg %lg %lg %lg", &m_a, &m_b, &m_c, &m_alpha, &m_beta, &m_gamma);
+					xmlFree (txt);
 				}
-			}
-			else if (!strcmp((gchar*)node->name, "size"))
-			{
-				txt = (char*)xmlNodeGetContent(node);
-				if (txt)
-				{
-					sscanf(txt, "%lg %lg %lg %lg %lg %lg", &m_xmin, &m_ymin, &m_zmin, &m_xmax, &m_ymax, &m_zmax);
-					xmlFree(txt);
+			} else if (!strcmp ((gchar*) node->name, "size")) {
+				txt = (char*) xmlNodeGetContent (node);
+				if (txt) {
+					sscanf (txt, "%lg %lg %lg %lg %lg %lg", &m_xmin, &m_ymin, &m_zmin, &m_xmax, &m_ymax, &m_zmax);
+					xmlFree (txt);
 				}
-				txt = (char*)xmlGetProp(node, (xmlChar*)"fixed");
-				if (txt)
-				{
-					if (!strcmp(txt, "true")) m_bFixedSize = true;
-					xmlFree(txt);
+				txt = (char*) xmlGetProp (node, (xmlChar*) "fixed");
+				if (txt) {
+					if (!strcmp (txt, "true"))
+						SetFixedSize (true);
+					xmlFree (txt);
 				}
-			}
-			else if (!strcmp((gchar*)node->name, "atom"))
-			{
-				gcAtom *pAtom = new gcAtom();
-				if (pAtom->LoadOld(node, version))
+			} else if (!strcmp((gchar*)node->name, "atom")) {
+				gcAtom *pAtom = new gcAtom ();
+				if (pAtom->LoadOld (node, version))
 					AddChild (pAtom);
 				else
 					delete pAtom;
-			}
-			else if (!strcmp((gchar*)node->name, "line"))
-			{
-				gcLine *pLine = new gcLine();
-				if (pLine->LoadOld(node, version)) LineDef.push_back((CrystalLine*)pLine);
-				else delete pLine;
-			}
-			else if (!strcmp((gchar*)node->name, "cleavage"))
-			{
-				gcCleavage *pCleavage = new gcCleavage();
-				if (pCleavage->LoadOld(node)) Cleavages.push_back((CrystalCleavage*)pCleavage);
-				else delete pCleavage;
-			}
-			else if (!strcmp( (gchar*) node->name, "view")) {
+			} else if (!strcmp ((gchar*) node->name, "line")) {
+				gcLine *pLine = new gcLine ();
+				if (pLine->LoadOld (node, version))
+					LineDef.push_back ((gcr::Line*) pLine);
+				else
+					delete pLine;
+			} else if (!strcmp((gchar*)node->name, "cleavage")) {
+				gcCleavage *pCleavage = new gcCleavage ();
+				if (pCleavage->LoadOld (node))
+					Cleavages.push_back ((gcr::Cleavage *) pCleavage);
+				else
+					delete pCleavage;
+			} else if (!strcmp( (gchar*) node->name, "view")) {
 				if (bViewLoaded) {
 					gcWindow *pWindow = new gcWindow (dynamic_cast <gcApplication *> (m_App), this);
 					gcView *pView = pWindow->GetView ();
@@ -580,23 +467,21 @@ void gcDocument::ParseXMLTree(xmlNode* xml)
 			node = node->next;
 		}
 	}
-	setlocale(LC_NUMERIC, old_num_locale);
-	g_free(old_num_locale);
-	Update();
+	Update ();
 }
 
-void gcDocument::OnNewDocument()
+void gcDocument::OnNewDocument ()
 {
-	Reinit();
-	UpdateAllViews();
+	Reinit ();
+	UpdateAllViews ();
 }
 
-typedef struct {int n; std::list<CrystalAtom*> l;} sAtom;
-typedef struct {int n; std::list<CrystalLine*> l;} sLine;
+typedef struct {int n; std::list<gcr::Atom*> l;} sAtom;
+typedef struct {int n; std::list<gcr::Line*> l;} sLine;
 
 void gcDocument::OnExportVRML (const string &FileName) const
 {
-	char *old_num_locale, tmp[128];
+	char tmp[128];
 	double x0, x1, x2, x3, x4, x5;
 	int n = 0;
 	try {
@@ -612,13 +497,11 @@ void gcDocument::OnExportVRML (const string &FileName) const
 		}
 		std::map<std::string, sAtom>AtomsMap;
 		std::map<std::string, sLine>LinesMap;
-		old_num_locale = g_strdup(setlocale(LC_NUMERIC, NULL));
-		setlocale(LC_NUMERIC, "C");
 
 		file << "#VRML V2.0 utf8" << endl;
-		
+
 		//Create prototypes for atoms
-		CrystalAtomList::const_iterator i;
+		gcr::AtomList::const_iterator i;
 		for (i = Atoms.begin(); i != Atoms.end(); i++)
 		{
 			(*i)->GetColor(&x0, &x1, &x2, &x3);
@@ -633,9 +516,9 @@ void gcDocument::OnExportVRML (const string &FileName) const
 			}
 			AtomsMap[tmp].l.push_back(*i);
 		}
-	
+
 		//Create prototypes for bonds
-		CrystalLineList::const_iterator j;
+		gcr::LineList::const_iterator j;
 		n = 0;
 		for (j = Lines.begin(); j != Lines.end(); j++)
 		{
@@ -651,15 +534,15 @@ void gcDocument::OnExportVRML (const string &FileName) const
 			}
 			LinesMap[tmp].l.push_back(*j);
 		}
-		
+
 		//world begin
 		m_pActiveView->GetBackgroundColor(&x0, &x1, &x2, &x3);
 		file << "Background{skyColor " << x0 << " " << x1 << " " << x2 << "}" << endl;
 		file << "Viewpoint {fieldOfView " << m_pActiveView->GetFoV()/90*1.570796326794897 <<"\tposition 0 0 " << m_pActiveView->GetPos() / 100 << "}" << endl;
 		m_pActiveView->GetRotation(&x0, &x1, &x2);
-		Matrix m(x0/90*1.570796326794897, x1/90*1.570796326794897, x2/90*1.570796326794897, euler);
+		gcu::Matrix m(x0/90*1.570796326794897, x1/90*1.570796326794897, x2/90*1.570796326794897, gcu::euler);
 		file << "Transform {" << endl << "\tchildren [" << endl;
-	
+
 		std::map<std::string, sAtom>::iterator k;
 		for (k = AtomsMap.begin(); k != AtomsMap.end(); k++)
 		{
@@ -678,7 +561,7 @@ void gcDocument::OnExportVRML (const string &FileName) const
 			(*k).second.l.clear();
 		}
 		AtomsMap.clear();
-		
+
 		std::map<std::string, sLine>::iterator l;
 		n = 0;
 		for (l = LinesMap.begin(); l != LinesMap.end(); l++)
@@ -695,7 +578,7 @@ void gcDocument::OnExportVRML (const string &FileName) const
 					x4 = (*j)->Y2();
 					x5 = (*j)->Z2();
 					m.Transform(x3, x4, x5);
-					CrystalLine line(gcu::unique, x0, x1, x2, x3, x4, x5, 0.0, 0.0, 0.0, 0.0, 0.0);
+					gcr::Line line(gcr::unique, x0, x1, x2, x3, x4, x5, 0.0, 0.0, 0.0, 0.0, 0.0);
 					line.GetRotation(x0, x1, x2, x3);
 					file << "\t\tTransform {" << endl << "\t\t\trotation " << x1 << " " << x2 << " " << x0 << " " << x3 << endl;
 					x0 = (line.X1() + line.X2()) / 200;
@@ -709,12 +592,10 @@ void gcDocument::OnExportVRML (const string &FileName) const
 			(*l).second.l.clear();
 		}
 		LinesMap.clear();
-		
+
 		//end of the world
 		file << "\t]" << endl << "}" << endl;
 
-		setlocale(LC_NUMERIC, old_num_locale);
-		g_free(old_num_locale);
 		g_output_stream_write (output, file.str ().c_str (), file.str ().size (), NULL, &error);
 		if (error) {
 			cerr << "gio error: " << error->message << endl;
@@ -786,7 +667,7 @@ bool gcDocument::VerifySaved()
 			if (m_filename == NULL) {
 				list<string> l;
 				l.push_front ("application/x-gcrystal");
-				FileChooser (m_App, true, l, this);
+				gcugtk::FileChooser (static_cast < gcugtk::Application * > (m_App), true, l, this);
 			}
 			if (m_filename)
 				Save ();
@@ -799,24 +680,24 @@ bool gcDocument::VerifySaved()
 	return (res != GTK_RESPONSE_CANCEL);
 }
 
-CrystalView* gcDocument::CreateNewView()
+gcr::View* gcDocument::CreateNewView()
 {
 	return new gcView(this);
 }
 
-CrystalAtom* gcDocument::CreateNewAtom()
+gcr::Atom* gcDocument::CreateNewAtom()
 {
-	return (CrystalAtom*) new gcAtom();
+	return (gcr::Atom*) new gcAtom();
 }
 
-CrystalLine* gcDocument::CreateNewLine()
+gcr::Line* gcDocument::CreateNewLine()
 {
-	return (CrystalLine*) new gcLine();
+	return (gcr::Line*) new gcLine();
 }
 
-CrystalCleavage* gcDocument::CreateNewCleavage()
+gcr::Cleavage* gcDocument::CreateNewCleavage()
 {
-	return (CrystalCleavage*) new gcCleavage();
+	return (gcr::Cleavage*) new gcCleavage();
 }
 
 const char* gcDocument::GetProgramId () const
@@ -826,7 +707,7 @@ const char* gcDocument::GetProgramId () const
 
 void gcDocument::SaveAsImage (const string &filename, char const *type, map<string, string>& options)
 {
-	m_pActiveView->SaveAsImage (filename, type, options, GetApp ()->GetImageWidth (), GetApp ()->GetImageHeight ());
+	m_pActiveView->SaveAsImage (filename, type, options, GetApp ()->GetImageWidth (), GetApp ()->GetImageHeight (), !m_App->GetTransparentBackground ());
 }
 
 bool gcDocument::LoadNewView (xmlNodePtr node)
@@ -841,7 +722,7 @@ bool gcDocument::LoadNewView (xmlNodePtr node)
 
 void gcDocument::RenameViews ()
 {
-	list <CrystalView *>::iterator i, iend = m_Views.end ();
+	list <gcr::View *>::iterator i, iend = m_Views.end ();
 	int n = 1, max = m_Views.size ();
 	for (i = m_Views.begin (); i != iend; i++) {
 		gcWindow *window = dynamic_cast <gcView*> (*i)->GetWindow ();
@@ -853,7 +734,7 @@ void gcDocument::RenameViews ()
 			gtk_window_set_title (w, t);
 			g_free (t);
 		} else
-			gtk_window_set_title (w, m_Label);
+			gtk_window_set_title (w, GetLabel ());
 		window->ActivateActionWidget ("ui/MainMenu/FileMenu/Save", !m_ReadOnly);
 		window->ActivateActionWidget ("ui/MainToolbar/Save", !m_ReadOnly);
 	}
@@ -895,7 +776,7 @@ bool gcDocument::SetProperty (unsigned property, char const *value)
 		m_Mail = g_strdup (value);
 		break;
 	default:
-		return CrystalDoc::SetProperty (property, value);
+		return gcr::Document::SetProperty (property, value);
 	}
 	return true;
 }
@@ -914,7 +795,7 @@ std::string gcDocument::GetProperty (unsigned property) const
 		g_free (m_Mail);
 		break;
 	default:
-		return CrystalDoc::GetProperty (property);
+		return gcr::Document::GetProperty (property);
 	}
 	return res;
 }
