@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Crystal
- * globals.h 
+ * globals.h
  *
- * Copyright (C) 2001-2003 Jean Brfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2009 Jean Brfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -22,7 +22,7 @@
  * USA
  */
 #include <glib.h>
-#include <goffice/app/go-conf.h>
+#include <goffice/goffice.h>
 
 bool IsEmbedded();
 
