@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Crystal
- * main.cc 
+ * main.cc
  *
- * Copyright (C) 2000-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2000-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -31,7 +31,6 @@
 #include "document.h"
 #include "view.h"
 #include "globals.h"
-#include <gtk/gtkglinit.h>
 #include <glib/gi18n.h>
 #include <cstdio>
 #include <cstring>
@@ -71,7 +70,7 @@ static void cb_print_version (G_GNUC_UNUSED const gchar *option_name, G_GNUC_UNU
 	exit (0);
 }
 
-static GOptionEntry entries[] = 
+static GOptionEntry entries[] =
 {
   { "version", 'v', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, (void*) cb_print_version, "prints Gnome Crystal version", NULL },
    { NULL, 0, 0, G_OPTION_ARG_NONE, NULL, NULL, NULL }
@@ -85,7 +84,6 @@ int main(int argc, char *argv[])
 	textdomain(GETTEXT_PACKAGE);
 
 	gtk_init (&argc, &argv);
-	gtk_gl_init (&argc, &argv);
 	Element::LoadRadii ();
 	if (argc > 1 && argv[1][0] == '-') {
 		context = g_option_context_new (_(" [file...]"));
@@ -102,7 +100,7 @@ int main(int argc, char *argv[])
 		argc --;
 		argv ++;
 	}
-	
+
 //Configuration loading
 	node = go_conf_get_node (Application::GetConfDir (), "crystal");
 	GCU_GCONF_GET ("printing/resolution", int, PrintResolution, 300)
@@ -129,13 +127,21 @@ int main(int argc, char *argv[])
 		if (strstr (*argv, "://"))
 			uri = g_strdup (*argv);
 		else {
-			path = g_path_is_absolute (*argv)? g_strdup (*argv): g_build_filename (g_get_current_dir (), *argv, NULL);
+			if (g_path_is_absolute (*argv))
+				path = g_strdup (*argv);
+			else {
+				char *dir = g_get_current_dir ();
+				path = g_build_filename (dir, *argv, NULL);
+				g_free (dir);
+			}
 			uri = g_filename_to_uri (path, NULL, NULL);
 			g_free (path);
 		}
 		if (bres)
 			pDoc = gcApp->OnFileNew ();
-		bres = gcApp->FileProcess (uri, go_get_mime_type (uri), false, NULL, pDoc);
+		char *mime_type = go_get_mime_type (uri);
+		bres = gcApp->FileProcess (uri, mime_type, false, NULL, pDoc);
+		g_free (mime_type);
 		g_free (uri);
 		argv++;
 	}
