@@ -1,13 +1,13 @@
 // -*- C++ -*-
 
-/* 
+/*
  * Gnome Crystal
- * window.cc 
+ * window.cc
  *
- * Copyright (C) 2006-2009 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2006-2011 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -29,8 +29,8 @@
 #include "document.h"
 #include "prefs.h"
 #include "view-settings.h"
-#include <gcu/crystalview.h>
-#include <gcu/print-setup-dlg.h>
+#include <gcr/view.h>
+#include <gcugtk/print-setup-dlg.h>
 #include <gcu/spacegroup.h>
 #include <glib/gi18n.h>
 #include <cstring>
@@ -77,7 +77,7 @@ static void on_file_close (G_GNUC_UNUSED GtkWidget *widget, gcWindow* Win)
 
 static void on_page_setup (G_GNUC_UNUSED GtkWidget *widget, gcWindow* Win)
 {
-	new PrintSetupDlg (Win->GetApplication (), Win->GetView ());
+	new gcugtk::PrintSetupDlg (Win->GetApplication (), Win->GetView ());
 }
 
 static void on_print_preview (G_GNUC_UNUSED GtkWidget *widget, gcWindow* Win)
@@ -118,17 +118,12 @@ static void on_prefs (G_GNUC_UNUSED GtkWidget* widget, gcWindow* Win)
 	new gcPrefsDlg (Win->GetApp ());
 }
 
-static void on_about_activate_url (G_GNUC_UNUSED GtkAboutDialog *about, const gchar *url, gpointer data)
-{
-	reinterpret_cast <gcWindow *> (data)->GetApp ()->OnWeb (url);
-}
-
-static void on_about (G_GNUC_UNUSED GtkWidget *widget, gcWindow* Win)
+static void on_about (G_GNUC_UNUSED GtkWidget *widget, G_GNUC_UNUSED gcWindow* Win)
 {
 	char const *authors[] = {"Jean Bréfort", NULL};
 //	char * documentors[] = {NULL};
 	char const *artists[] = {"Nestor Diaz", NULL};
-	char license[] = "This program is free software; you can redistribute it and/or\n" 
+	char license[] = "This program is free software; you can redistribute it and/or\n"
 		"modify it under the terms of the GNU General Public License as\n"
  		"published by the Free Software Foundation; either version 2 of the\n"
 		"License, or (at your option) any later version.\n\n"
@@ -141,22 +136,21 @@ static void on_about (G_GNUC_UNUSED GtkWidget *widget, gcWindow* Win)
 		"Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301\n"
 		"USA";
 
-	gtk_about_dialog_set_url_hook (on_about_activate_url, Win, NULL);
 /* Note to translators: replace the following string with the appropriate credits for you lang */
 	char const *translator_credits = _("translator_credits");
 	GdkPixbuf *logo = gdk_pixbuf_new_from_file (PIXMAPSDIR"/gcrystal_logo.png", NULL);
 	gtk_show_about_dialog (NULL,
-					"name", _("Gnome Crystal"),
+					"program-name", _("Gnome Crystal"),
 					"authors", authors,
 					"artists", artists,
 					"comments", _("Gnome Crystal is a lightweight crystal structures viewer for Gnome"),
 					"copyright", _("Copyright © 1999-2010 by Jean Bréfort"),
 					"license", license,
 					"logo", logo,
-					"translator_credits", strcmp (translator_credits, "translator_credits") != 0 ? 
+					"translator_credits", strcmp (translator_credits, "translator_credits") != 0 ?
 											translator_credits : NULL,
 					"version", VERSION,
-					"website", "http://www.nongnu.org/gchemutils",
+					"website", "http://gchemutils.nongnu.org",
 					NULL);
 	g_object_unref (logo);
 }
@@ -393,7 +387,7 @@ static const char *ui_description =
 
 gcWindow::gcWindow (gcApplication *App, gcDocument *Doc)
 {
-	GtkWidget *vbox;
+	GtkWidget *grid;
 	GtkWidget *bar;
 	GtkActionGroup *action_group;
 	GtkAccelGroup *accel_group;
@@ -407,8 +401,9 @@ gcWindow::gcWindow (gcApplication *App, gcDocument *Doc)
 	gtk_window_set_default_size (m_Window, 300, 380);
 	g_signal_connect (G_OBJECT (m_Window), "delete-event", G_CALLBACK (on_delete_event), this);
 	g_signal_connect (G_OBJECT (m_Window), "focus_in_event", G_CALLBACK (on_focus_in), this);
-	vbox = gtk_vbox_new (FALSE, 0);
-	gtk_container_add (GTK_CONTAINER (m_Window), vbox);
+	grid = gtk_grid_new ();
+	g_object_set (G_OBJECT (grid), "orientation", GTK_ORIENTATION_VERTICAL, NULL);
+	gtk_container_add (GTK_CONTAINER (m_Window), grid);
 	action_group = gtk_action_group_new ("MenuActions");
 	gtk_action_group_set_translation_domain (action_group, GETTEXT_PACKAGE);
 	gtk_action_group_add_actions (action_group, entries, G_N_ELEMENTS (entries), this);
@@ -422,7 +417,7 @@ gcWindow::gcWindow (gcApplication *App, gcDocument *Doc)
 
 	accel_group = gtk_ui_manager_get_accel_group (m_UIManager);
 	gtk_window_add_accel_group (GTK_WINDOW (m_Window), accel_group);
-	
+
 	error = NULL;
 	if (!gtk_ui_manager_add_ui_from_string (m_UIManager, ui_description, -1, &error)) {
 		g_message ("building menus failed: %s", error->message);
@@ -434,7 +429,12 @@ gcWindow::gcWindow (gcApplication *App, gcDocument *Doc)
 	GtkWidget *w = gtk_recent_chooser_menu_new_for_manager (App->GetRecentManager ());
 	gtk_recent_chooser_set_sort_type (GTK_RECENT_CHOOSER (w), GTK_RECENT_SORT_MRU);
 	GtkRecentFilter *filter = gtk_recent_filter_new ();
-	gtk_recent_filter_add_mime_type (filter, "application/x-gcrystal");
+	std::list<std::string>::iterator it;
+	char const * mime = App->GetFirstSupportedMimeType (it);
+	while (mime) {
+		gtk_recent_filter_add_mime_type (filter, mime);
+		mime = App->GetNextSupportedMimeType (it);
+	}
 	gtk_recent_chooser_add_filter (GTK_RECENT_CHOOSER (w), filter);
 	g_signal_connect (G_OBJECT (w), "item-activated", G_CALLBACK (on_recent), this);
 	GtkWidget *item = gtk_menu_item_new_with_label (_("Open recent"));
@@ -443,9 +443,9 @@ gcWindow::gcWindow (gcApplication *App, gcDocument *Doc)
 	gtk_menu_shell_insert (GTK_MENU_SHELL (gtk_widget_get_parent (menu)), item, 3);
 
 	bar = gtk_ui_manager_get_widget (m_UIManager, "/MainMenu");
-	gtk_box_pack_start (GTK_BOX (vbox), bar, false, false, 0);
+	gtk_container_add (GTK_CONTAINER (grid), bar);
 	bar = gtk_ui_manager_get_widget (m_UIManager, "/MainToolbar");
-	gtk_box_pack_start (GTK_BOX (vbox), bar, false, false, 0);
+	gtk_container_add (GTK_CONTAINER (grid), bar);
 	m_View = dynamic_cast<gcView *> (m_Doc->GetView ());
 	if (m_View->GetWindow () != NULL) {
 		m_View = dynamic_cast<gcView *> (m_Doc->CreateNewView ());
@@ -453,19 +453,21 @@ gcWindow::gcWindow (gcApplication *App, gcDocument *Doc)
 		m_Doc->AddView (m_View);
 	} else
 		m_View->SetWindow (this);
-	gtk_box_pack_start (GTK_BOX (vbox), m_View->GetWidget (), true, true, 0);
+	g_object_set (G_OBJECT (m_View->GetWidget ()), "margin-left", 6, "margin-right", 6, "expand", true, NULL);
+	gtk_container_add (GTK_CONTAINER (grid), m_View->GetWidget ());
 	m_Bar = gtk_statusbar_new ();
 	m_statusId = gtk_statusbar_get_context_id (GTK_STATUSBAR (m_Bar), "status");
 	gtk_statusbar_push (GTK_STATUSBAR (m_Bar), m_statusId, _("Ready"));
 	m_MessageId = 0;
 	ClearStatus ();
-	gtk_box_pack_start (GTK_BOX (vbox), m_Bar, false, false, 0);
-	
+	gtk_container_add (GTK_CONTAINER (grid), m_Bar);
+
 	gtk_widget_show_all (GTK_WIDGET (m_Window));
 }
 
 gcWindow::~gcWindow ()
 {
+	g_object_unref (m_UIManager);
 }
 
 void gcWindow::ClearStatus()
